@@ -22,6 +22,7 @@
 #ifdef THREADING_MODEL_FORK
 #include <algorithm>
 #include <iostream>
+#include <sys/select.h>
 #include <sys/wait.h>
 #include <unistd.h>
 #include <fcntl.h>
@@ -185,7 +186,7 @@ unsigned int ThreadExecutor::check()
                 fileChecker.settings() = _settings;
                 unsigned int resultOfCheck = 0;
 
-                if (_fileContents.size() > 0 && _fileContents.find(i->first) != _fileContents.end()) {
+                if (!_fileContents.empty() && _fileContents.find(i->first) != _fileContents.end()) {
                     // File content was given as a string
                     resultOfCheck = fileChecker.check(i->first, _fileContents[ i->first ]);
                 } else {
@@ -219,7 +220,7 @@ unsigned int ThreadExecutor::check()
                     if (FD_ISSET(*rp, &rfds)) {
                         int readRes = handleRead(*rp, result);
                         if (readRes == -1) {
-                            long size = 0;
+                            std::size_t size = 0;
                             std::map<int, std::string>::iterator p = pipeFile.find(*rp);
                             if (p != pipeFile.end()) {
                                 std::string name = p->second;
@@ -407,14 +408,15 @@ unsigned int __stdcall ThreadExecutor::threadProc(void *args)
 
         }
         const std::string &file = it->first;
-        const int fileSize = it->second;
-        it++;
+        const std::size_t fileSize = it->second;
+        ++it;
 
         LeaveCriticalSection(&threadExecutor->_fileSync);
 
-        if (!threadExecutor->_fileContents.empty() && threadExecutor->_fileContents.find(file) != threadExecutor->_fileContents.end()) {
+        std::map<std::string, std::string>::const_iterator fileContent = threadExecutor->_fileContents.find(file);
+        if (fileContent != threadExecutor->_fileContents.end()) {
             // File content was given as a string
-            result += fileChecker.check(file, threadExecutor->_fileContents[file]);
+            result += fileChecker.check(file, fileContent->second);
         } else {
             // Read file from a file
             result += fileChecker.check(file);
