@@ -28,7 +28,7 @@
 #define THREADING_MODEL_FORK
 #elif defined(_WIN32)
 #define THREADING_MODEL_WIN
-#include <Windows.h>
+#include <windows.h>
 #endif
 
 class Settings;
@@ -102,10 +102,10 @@ private:
 
     std::map<std::string, std::string> _fileContents;
     std::map<std::string, std::size_t>::const_iterator _itNextFile;
-    unsigned int _processedFiles;
-    unsigned int _totalFiles;
-    size_t       _processedSize;
-    size_t       _totalFileSize;
+    std::size_t _processedFiles;
+    std::size_t _totalFiles;
+    std::size_t _processedSize;
+    std::size_t _totalFileSize;
     CRITICAL_SECTION _fileSync;
 
     std::list<std::string> _errorList;
