@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2012 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2013 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,6 @@
 #define APPLICATIONDIALOG_H
 
 #include <QDialog>
-#include <QLineEdit>
 #include <QString>
 #include "application.h"
 #include "ui_application.h"
@@ -46,16 +45,10 @@ public:
     * @param app Application definition.
     * @param parent Parent widget.
     */
-    ApplicationDialog(const QString &title, const Application &app,
+    ApplicationDialog(const QString &title, Application &app,
                       QWidget *parent = 0);
     virtual ~ApplicationDialog();
 
-    /**
-    * @brief Get modified application
-    * @return Modified name
-    */
-    Application GetApplication() const;
-
 protected slots:
 
     void Ok();
@@ -73,6 +66,13 @@ protected:
     *
     */
     Ui::ApplicationDialog mUI;
+
+private:
+
+    /**
+    * @brief Underlying Application
+    */
+    Application& mApplication;
 };
 /// @}
 #endif // APPLICATIONDIALOG_H
