@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2012 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2013 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,6 @@
 #define APPLICATIONLIST_H
 
 #include <QObject>
-#include <QSettings>
 #include "application.h"
 
 /// @addtogroup GUI
@@ -49,7 +48,7 @@ public:
     /**
     * @brief Save all applications
     */
-    void SaveSettings();
+    void SaveSettings() const;
 
     /**
     * @brief Get the amount of applications in the list
@@ -63,7 +62,8 @@ public:
     * @param index Index of the application whose name to get
     * @return Name of the application
     */
-    Application GetApplication(const int index) const;
+    const Application& GetApplication(const int index) const;
+    Application& GetApplication(const int index);
 
     /**
     * @brief Return the default application.
@@ -73,14 +73,6 @@ public:
         return mDefaultApplicationIndex;
     }
 
-    /**
-    * @brief Modify an application
-    *
-    * @param index Index of the application to modify
-    * @param app Application with new data.
-    */
-    void SetApplication(int index, const Application &app);
-
     /**
     * @brief Add a new application
     *
