@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2012 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2013 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,6 @@
  */
 
 #include <QDebug>
-#include "common.h"
 #include "checkstatistics.h"
 
 CheckStatistics::CheckStatistics(QObject *parent)
@@ -66,30 +65,22 @@ void CheckStatistics::Clear()
 
 unsigned CheckStatistics::GetCount(ShowTypes::ShowType type) const
 {
-    unsigned count = 0;
     switch (type) {
     case ShowTypes::ShowStyle:
-        count = mStyle;
-        break;
+        return mStyle;
     case ShowTypes::ShowWarnings:
-        count = mWarning;
-        break;
+        return mWarning;
     case ShowTypes::ShowPerformance:
-        count = mPerformance;
-        break;
+        return mPerformance;
     case ShowTypes::ShowPortability:
-        count = mPortability;
-        break;
+        return mPortability;
     case ShowTypes::ShowErrors:
-        count = mError;
-        break;
+        return mError;
     case ShowTypes::ShowInformation:
-        count = mInformation;
-        break;
+        return mInformation;
     case ShowTypes::ShowNone:
     default:
         qDebug() << "Unknown error type - returning zero statistics.";
-        break;
+        return 0;
     }
-    return count;
 }
