@@ -19,6 +19,8 @@
 #ifndef COMMON_H
 #define COMMON_H
 
+#include <QString>
+
 /// @addtogroup GUI
 /// @{
 
@@ -54,12 +56,14 @@
 #define SETTINGS_SHOW_PORTABILITY       "Show portability"
 
 // Standards support
+#define SETTINGS_STD_CPP03              "Platform CPP03"
 #define SETTINGS_STD_CPP11              "Platform CPP11"
+#define SETTINGS_STD_C89                "Platform C89"
 #define SETTINGS_STD_C99                "Platform C99"
+#define SETTINGS_STD_C11                "Platform C11"
 #define SETTINGS_STD_POSIX              "Platform Posix"
 
 // Other settings
-#define SETTINGS_CHECK_PATH             "Check path"
 #define SETTINGS_CHECK_FORCE            "Check force"
 #define SETTINGS_CHECK_THREADS          "Check threads"
 #define SETTINGS_SHOW_FULL_PATH         "Show full path"
@@ -82,7 +86,31 @@
 #define PROGRESS_MAX                    1024.0
 
 #define SETTINGS_CHECKED_PLATFORM       "Checked platform"
+
+#define SETTINGS_LAST_CHECK_PATH        "Last check path"
 #define SETTINGS_LAST_PROJECT_PATH      "Last project path"
+#define SETTINGS_LAST_RESULT_PATH       "Last result path"
+#define SETTINGS_LAST_SOURCE_PATH       "Last source path"
+#define SETTINGS_LAST_INCLUDE_PATH      "Last include path"
+#define SETTINGS_LAST_APP_PATH          "Last application path"
+
+
+/**
+ * @brief Obtains the path of specified type
+ * Returns the path of specified type if not empty. Otherwise returns last check
+ * path if valid or user's home directory.
+ * @param type Type of path to obtain
+ * @return Best path fo provided type
+ */
+QString GetPath(const QString &type);
+
+/**
+ * @brief Stores last used path of specified type
+ * Stores provided path as last used path for specified type.
+ * @param type Type of the path to store
+ * @param value Path to store
+ */
+void SetPath(const QString &type, const QString &value);
 
 /// @}
 #endif
