@@ -26,7 +26,7 @@ General Public License version 3</translation>
         <translation>Visitez le site Cppcheck : %1</translation>
     </message>
     <message utf8="true">
-        <source>Copyright © 2007-2012 Daniel Marjamäki and cppcheck team.</source>
+        <source>Copyright © 2007-2013 Daniel Marjamäki and cppcheck team.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -104,18 +104,10 @@ Parameters: -l(line) (file)</source>
         <source>Checking Log</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>&amp;Save</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Clear</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Close</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Save Log</source>
         <translation type="unfinished"></translation>
@@ -499,14 +491,6 @@ Do you want to stop the checking and exit Cppcheck?.</source>
 This is probably because the settings were changed between the Cppcheck versions. Please check (and fix) the editor application settings, otherwise the editor program might not start correctly.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Failed to change the user interface language:
-
-%1
-
-The user interface language has been reset to English. Open the Preferences-dialog to select any of the available languages.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Spanish</source>
         <translation type="unfinished"></translation>
@@ -615,6 +599,44 @@ Opening a new XML file will clear current results.Do you want to proceed?</sourc
         <source>Select files to check</source>
         <translation type="unfinished">Sélectionner les fichiers à vérifier</translation>
     </message>
+    <message>
+        <source>Cppcheck GUI.
+
+Syntax:
+    cppcheck-gui [OPTIONS] [files or paths]
+
+Options:
+    -h, --help     Print this help
+    -p &lt;file&gt;      Open given project file and start checking it
+    -l &lt;file&gt;      Open given results xml file
+    -d &lt;directory&gt; Specify the directory that was checked to generate the results xml specified with -l
+    -v, --version  Show program version</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cppcheck GUI - Command line parameters</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>C++ standard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>C standard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>C11</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>C89</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>C++03</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Platforms</name>
@@ -732,6 +754,25 @@ Opening a new XML file will clear current results.Do you want to proceed?</sourc
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>QDialogButtonBox</name>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Close</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -863,6 +904,10 @@ Please select the default editor application in preferences/Applications.</sourc
         <source>Copy message id</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Hide all with id</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ResultsView</name>
@@ -928,13 +973,6 @@ Pour configurer les erreurs affichées, ouvrez le menu d&apos;affichage.</transl
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>SelectFilesDialog</name>
-    <message>
-        <source>Select files to check</source>
-        <translation type="obsolete">Sélectionner les fichiers à vérifier</translation>
-    </message>
-</context>
 <context>
     <name>Settings</name>
     <message>
@@ -1227,6 +1265,21 @@ Pour configurer les erreurs affichées, ouvrez le menu d&apos;affichage.</transl
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>TranslationHandler</name>
+    <message>
+        <source>Failed to change the user interface language:
+
+%1
+
+The user interface language has been reset to English. Open the Preferences-dialog to select any of the available languages.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cppcheck</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>TxtReport</name>
     <message>
