@@ -17,7 +17,7 @@
     </message>
     <message utf8="true">
         <source>Copyright © 2007-2012 Daniel Marjamäki and cppcheck team.</source>
-        <translation>Copyright © 2007-2012 Daniel Marjamäki and cppcheck team.</translation>
+        <translation type="obsolete">Copyright © 2007-2012 Daniel Marjamäki and cppcheck team.</translation>
     </message>
     <message>
         <source>This program is licensed under the terms
@@ -29,6 +29,10 @@ of the GNU General Public License version 3</source>
         <source>Visit Cppcheck homepage at %1</source>
         <translation>Cppcheck 홈페이지(%1)를 방문해보세요</translation>
     </message>
+    <message utf8="true">
+        <source>Copyright © 2007-2013 Daniel Marjamäki and cppcheck team.</source>
+        <translation type="unfinished">Copyright © 2007-2012 Daniel Marjamäki and cppcheck team. {2007-2013 ?}</translation>
+    </message>
 </context>
 <context>
     <name>ApplicationDialog</name>
@@ -118,18 +122,10 @@ Kate로 파일을 열고, 해당 행으로 이동하는 예제:
         <source>Checking Log</source>
         <translation>로그 확인</translation>
     </message>
-    <message>
-        <source>&amp;Save</source>
-        <translation>저장(&amp;S)</translation>
-    </message>
     <message>
         <source>Clear</source>
         <translation>지우기</translation>
     </message>
-    <message>
-        <source>Close</source>
-        <translation>닫기</translation>
-    </message>
     <message>
         <source>Save Log</source>
         <translation>로그 저장</translation>
@@ -539,7 +535,7 @@ Do you want to stop the checking and exit Cppcheck?.</source>
 %1
 
 The user interface language has been reset to English. Open the Preferences-dialog to select any of the available languages.</source>
-        <translation>언어 변경 실패:
+        <translation type="obsolete">언어 변경 실패:
 
 %1
 
@@ -647,6 +643,44 @@ Opening a new XML file will clear current results.Do you want to proceed?</sourc
         <source>Select files to check</source>
         <translation type="unfinished">검사할 파일 선택</translation>
     </message>
+    <message>
+        <source>Cppcheck GUI.
+
+Syntax:
+    cppcheck-gui [OPTIONS] [files or paths]
+
+Options:
+    -h, --help     Print this help
+    -p &lt;file&gt;      Open given project file and start checking it
+    -l &lt;file&gt;      Open given results xml file
+    -d &lt;directory&gt; Specify the directory that was checked to generate the results xml specified with -l
+    -v, --version  Show program version</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cppcheck GUI - Command line parameters</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>C++ standard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>C standard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>C11</source>
+        <translation type="unfinished">C11</translation>
+    </message>
+    <message>
+        <source>C89</source>
+        <translation type="unfinished">C89</translation>
+    </message>
+    <message>
+        <source>C++03</source>
+        <translation type="unfinished">C++03</translation>
+    </message>
 </context>
 <context>
     <name>Platforms</name>
@@ -764,6 +798,25 @@ Opening a new XML file will clear current results.Do you want to proceed?</sourc
         <translation>무시할 디렉토리 선택</translation>
     </message>
 </context>
+<context>
+    <name>QDialogButtonBox</name>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Close</source>
+        <translation type="unfinished">닫기</translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -901,6 +954,10 @@ Please select the directory where file is located.</source>
         <source>Copy message id</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Hide all with id</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ResultsView</name>
@@ -966,17 +1023,6 @@ To toggle what kind of errors are shown, open view menu.</source>
         <translation type="unfinished">검사</translation>
     </message>
 </context>
-<context>
-    <name>SelectFilesDialog</name>
-    <message>
-        <source>Select files to check</source>
-        <translation type="obsolete">검사할 파일 선택</translation>
-    </message>
-    <message>
-        <source>Check</source>
-        <translation type="obsolete">검사</translation>
-    </message>
-</context>
 <context>
     <name>Settings</name>
     <message>
@@ -1269,6 +1315,25 @@ To toggle what kind of errors are shown, open view menu.</source>
         <translation>%2 중 %1 파일 검사됨</translation>
     </message>
 </context>
+<context>
+    <name>TranslationHandler</name>
+    <message>
+        <source>Failed to change the user interface language:
+
+%1
+
+The user interface language has been reset to English. Open the Preferences-dialog to select any of the available languages.</source>
+        <translation type="unfinished">언어 변경 실패:
+
+%1
+
+언어가 영어로 초기화 됐습니다. 설정창을 열어서 설정 가능한 언어를 선택하세요.</translation>
+    </message>
+    <message>
+        <source>Cppcheck</source>
+        <translation type="unfinished">Cppcheck</translation>
+    </message>
+</context>
 <context>
     <name>TxtReport</name>
     <message>
