@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2012 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2013 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,29 +24,16 @@ ErrorItem::ErrorItem()
 {
 }
 
-ErrorItem::ErrorItem(const ErrorItem &item)
-{
-    file = item.file;
-    file0 = item.file0;
-    files = item.files;
-    lines = item.lines;
-    errorId = item.errorId;
-    inconclusive = item.inconclusive;
-    severity = item.severity;
-    summary = item.summary;
-    message = item.message;
-}
-
 ErrorItem::ErrorItem(const ErrorLine &line)
+    : file(line.file)
+    , files(line.file)
+    , errorId(line.errorId)
+    , severity(line.severity)
+    , inconclusive(line.inconclusive)
+    , summary(line.summary)
+    , message(line.message)
 {
-    file = line.file;
-    files.append(line.file);
     lines.append(line.line);
-    errorId = line.errorId;
-    inconclusive = line.inconclusive;
-    severity = line.severity;
-    summary = line.summary;
-    message = line.message;
 }
 
 QString ErrorItem::ToString() const
