@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2012 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2013 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,53 +32,17 @@ class ErrorLine;
 
 /**
  * @brief GUI versions of severity conversions.
- * GUI needs its own versions of conversions since GUI uses Qt's QString
+ * GUI needs wrappers for conversion functions since GUI uses Qt's QString
  * instead of the std::string used by lib/cli.
  */
-class GuiSeverity : Severity {
+class GuiSeverity {
 public:
-    static QString toString(SeverityType severity) {
-        switch (severity) {
-        case none:
-            return "";
-        case error:
-            return "error";
-        case warning:
-            return "warning";
-        case style:
-            return "style";
-        case performance:
-            return "performance";
-        case portability:
-            return "portability";
-        case information:
-            return "information";
-        case debug:
-            return "debug";
-        };
-        return "???";
+    static QString toString(Severity::SeverityType severity) {
+        return QString(Severity::toString(severity).c_str());
     }
 
-    static SeverityType fromString(const QString &severity) {
-        if (severity.isEmpty())
-            return none;
-        if (severity == "none")
-            return none;
-        if (severity == "error")
-            return error;
-        if (severity == "warning")
-            return warning;
-        if (severity == "style")
-            return style;
-        if (severity == "performance")
-            return performance;
-        if (severity == "portability")
-            return portability;
-        if (severity == "information")
-            return information;
-        if (severity == "debug")
-            return debug;
-        return none;
+    static Severity::SeverityType fromString(const QString &severity) {
+        return Severity::fromString(severity.toStdString());
     }
 };
 
@@ -93,9 +57,7 @@ public:
 class ErrorItem {
 public:
     ErrorItem();
-    ErrorItem(const ErrorItem &item);
     ErrorItem(const ErrorLine &line);
-    ~ErrorItem() { }
 
     /**
     * @brief Convert error item to string.
