@@ -16,43 +16,57 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
 #include <QApplication>
 #include <QCoreApplication>
 #include <QTextCodec>
 #include <QMetaType>
 #include <QStringList>
+#include <QSettings>
 #ifdef _WIN32
 #include <QMessageBox>
 #else
 #include <iostream>
 #endif
+#include "cppcheck.h"
+#include "common.h"
 #include "mainwindow.h"
 #include "erroritem.h"
+#include "aboutdialog.h"
+#include "translationhandler.h"
+
 
 void ShowUsage();
+void ShowVersion();
 bool CheckArgs(const QStringList &args);
 
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
 
-    if (!CheckArgs(app.arguments()))
-        return 0;
+#if QT_VERSION < 0x050000
+    // Set codecs so that UTF-8 strings in sources are handled correctly.
+    // This is ONLY needed for Qt versions 4.x.
+    // Qt 5.x assumes UTF-8 by default.
+    QTextCodec::setCodecForTr(QTextCodec::codecForName("UTF-8"));
+    QTextCodec::setCodecForCStrings(QTextCodec::codecForName("UTF-8"));
+#endif
 
     QCoreApplication::setOrganizationName("Cppcheck");
     QCoreApplication::setApplicationName("Cppcheck-GUI");
 
+    TranslationHandler* th = new TranslationHandler(&app);
+    QSettings* settings = new QSettings("Cppcheck", "Cppcheck-GUI", &app);
+    th->SetLanguage(settings->value(SETTINGS_LANGUAGE, th->SuggestLanguage()).toString());
+
+    if (!CheckArgs(app.arguments()))
+        return 0;
+
     app.setWindowIcon(QIcon(":icon.png"));
 
     // Register this metatype that is used to transfer error info
     qRegisterMetaType<ErrorItem>("ErrorItem");
 
-    // Set codecs so that UTF-8 strings in sources are handled correctly.
-    QTextCodec::setCodecForTr(QTextCodec::codecForName("UTF-8"));
-    QTextCodec::setCodecForCStrings(QTextCodec::codecForName("UTF-8"));
-
-    MainWindow window;
+    MainWindow window(th, settings);
     window.show();
     return app.exec();
 }
@@ -65,26 +79,50 @@ bool CheckArgs(const QStringList &args)
         ShowUsage();
         return false;
     }
+    if (args.contains("-v") || args.contains("--version")) {
+        ShowVersion();
+        return false;
+    }
     return true;
 }
 
 void ShowUsage()
 {
-    const char helpMessage[] =
-        "Cppcheck GUI.\n\n"
-        "Syntax:\n"
-        "    cppcheck-gui [OPTIONS] [files or paths]\n\n"
-        "Options:\n"
-        "    -h, --help    Print this help\n"
-        "    -p <file>     Open given project file and start checking it\n";
+    QString helpMessage = MainWindow::tr(
+                              "Cppcheck GUI.\n\n"
+                              "Syntax:\n"
+                              "    cppcheck-gui [OPTIONS] [files or paths]\n\n"
+                              "Options:\n"
+                              "    -h, --help     Print this help\n"
+                              "    -p <file>      Open given project file and start checking it\n"
+                              "    -l <file>      Open given results xml file\n"
+                              "    -d <directory> Specify the directory that was checked to generate the results xml specified with -l\n"
+                              "    -v, --version  Show program version");
 #if defined(_WIN32)
     QMessageBox msgBox(QMessageBox::Information,
-                       "Cppcheck GUI",
+                       MainWindow::tr("Cppcheck GUI - Command line parameters"),
                        helpMessage,
                        QMessageBox::Ok
                       );
     (void)msgBox.exec();
 #else
-    std::cout << helpMessage;
+    std::cout << helpMessage.toStdString() << std::endl;
+#endif
+}
+
+void ShowVersion()
+{
+#if defined(_WIN32)
+    AboutDialog *dlg = new AboutDialog(CppCheck::version(), CppCheck::extraVersion(), 0);
+    dlg->exec();
+    delete dlg;
+#else
+    std::string versionMessage("Cppcheck ");
+    versionMessage += CppCheck::version();
+    const char * extraVersion = CppCheck::extraVersion();
+    if (*extraVersion != 0)
+        versionMessage += std::string(" (") + extraVersion + ")";
+
+    std::cout << versionMessage << std::endl;
 #endif
 }
