@@ -54,7 +54,7 @@ public:
     */
     enum { MaxRecentProjects = 5 };
 
-    MainWindow();
+    MainWindow(TranslationHandler* th, QSettings* settings);
     virtual ~MainWindow();
 
     /**
@@ -94,7 +94,7 @@ public slots:
     * @brief Slot to open XML report file
     *
     */
-    void OpenXML();
+    void OpenResults();
 
     /**
     * @brief Show errors with type "style"
@@ -405,6 +405,19 @@ private:
     */
     void HandleCLIParams(const QStringList &params);
 
+    /**
+    * @brief Load XML file to the GUI.
+    * @param file Filename (inc. path) of XML file to load.
+    */
+    void LoadResults(const QString file);
+
+    /**
+    * @brief Load XML file to the GUI.
+    * @param file Filename (inc. path) of XML file to load.
+    * @param checkedDirectory Path to the directory that the results were generated for.
+    */
+    void LoadResults(const QString file, const QString checkedDirectory);
+
     /**
     * @brief Load project file to the GUI.
     * @param filePath Filename (inc. path) of project file to load.
@@ -493,6 +506,11 @@ private:
     */
     QActionGroup *mPlatformActions;
 
+    /**
+    * @brief GUI actions for selecting the coding standard.
+    */
+    QActionGroup *mCStandardActions, *mCppStandardActions;
+
     /**
     * @brief Are we exiting the cppcheck?
     * If this is true then the cppcheck is waiting for check threads to exit
