@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2012 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2013 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -82,7 +82,7 @@ bool Project::Open()
     return false;
 }
 
-void Project::Edit()
+bool Project::Edit()
 {
     ProjectFileDialog dlg(mFilename, mParentWidget);
     QString root = mPFile->GetRootPath();
@@ -118,7 +118,9 @@ void Project::Edit()
                             mParentWidget);
             msg.exec();
         }
+        return writeSuccess;
     }
+    return false;
 }
 
 void Project::Create()
