@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2012 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2013 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -82,7 +82,7 @@ public:
     * @brief Get filename for the project file.
     * @return file name.
     */
-    QString GetFilename() {
+    QString GetFilename() const {
         return mFilename;
     }
 
@@ -108,13 +108,13 @@ public:
 
     /**
     * @brief Set list of paths to check.
-    * @param defines List of paths.
+    * @param paths List of paths.
     */
     void SetCheckPaths(const QStringList &paths);
 
     /**
     * @brief Set list of paths to exclude from the check.
-    * @param defines List of paths.
+    * @param paths List of paths.
     */
     void SetExcludedPaths(const QStringList &paths);
 
