@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2012 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2013 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,7 +22,6 @@
 #include <QStringList>
 #include <QFileInfo>
 #include <QFileDialog>
-#include <QLineEdit>
 #include <QDir>
 #include <QSettings>
 #include "common.h"
@@ -66,7 +65,7 @@ void ProjectFileDialog::LoadSettings()
            settings.value(SETTINGS_PROJECT_DIALOG_HEIGHT, 330).toInt());
 }
 
-void ProjectFileDialog::SaveSettings()
+void ProjectFileDialog::SaveSettings() const
 {
     QSettings settings;
     settings.setValue(SETTINGS_PROJECT_DIALOG_WIDTH, size().width());
