@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2012 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2013 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,11 +19,9 @@
 #include <QObject>
 #include <QString>
 #include <QFile>
-#include "erroritem.h"
 #include "report.h"
 
-Report::Report(const QString &filename, QObject * parent) :
-    QObject(parent),
+Report::Report(const QString &filename) :
     mFilename(filename)
 {
 }
