@@ -56,7 +56,7 @@ public:
     *
     * @param item Error item data
     */
-    void AddErrorItem(const ErrorItem &item);
+    bool AddErrorItem(const ErrorItem &item);
 
     /**
     * @brief Clear all errors from the tree
@@ -217,6 +217,12 @@ protected slots:
     */
     void HideResult();
 
+    /**
+    * @brief Slot for context menu item to hide all messages with the current message Id
+    *
+    */
+    void HideAllIdResult();
+
     /**
     * @brief Slot for selection change in the results tree.
     *
