@@ -242,7 +242,7 @@ void SettingsDialog::EditApplication()
 void SettingsDialog::DefaultApplication()
 {
     QList<QListWidgetItem *> selected = mUI.mListWidget->selectedItems();
-    if (selected.size() > 0) {
+    if (!selected.isEmpty()) {
         int index = mUI.mListWidget->row(selected[0]);
         mTempApplications->SetDefault(index);
         mUI.mListWidget->clear();
@@ -310,10 +310,11 @@ void SettingsDialog::AddIncludePath()
 {
     QString selectedDir = QFileDialog::getExistingDirectory(this,
                           tr("Select include directory"),
-                          QString());
+                          GetPath(SETTINGS_LAST_INCLUDE_PATH));
 
     if (!selectedDir.isEmpty()) {
         AddIncludePath(selectedDir);
+        SetPath(SETTINGS_LAST_INCLUDE_PATH, selectedDir);
     }
 }
 
