@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2012 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2013 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -70,7 +70,7 @@ public:
     /**
      * @brief Save visibility settings to the platform's settings storage.
      */
-    void save();
+    void save() const;
 
     /**
      * @brief Is the showtype visible in the GUI?
@@ -89,9 +89,9 @@ public:
     /**
      * @brief Show/hide the showtype.
      * @param category Showtype whose visibility to set.
-     * @return true if the severity is set visible.
+     * @param showing true if the severity is set visible.
      */
-    void show(ShowTypes::ShowType category, bool show);
+    void show(ShowTypes::ShowType category, bool showing);
 
     /**
      * @brief Convert severity string to ShowTypes value
