@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2012 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2013 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +23,6 @@
 #include <QMutex>
 #include <QObject>
 #include <QStringList>
-#include <QVariant>
 #include "errorlogger.h"
 
 class ErrorItem;
@@ -63,7 +62,7 @@ public:
     * @brief Get the number of files to check
     *
     */
-    int GetFileCount();
+    int GetFileCount() const;
 
     /**
     * ErrorLogger methods
