@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2012 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2013 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,10 +19,7 @@
 #ifndef TXT_REPORT_H
 #define TXT_REPORT_H
 
-#include <QObject>
 #include <QString>
-#include <QStringList>
-#include <QFile>
 #include <QTextStream>
 #include "report.h"
 
@@ -38,7 +35,7 @@ class TxtReport : public Report {
     Q_OBJECT
 
 public:
-    TxtReport(const QString &filename, QObject * parent = 0);
+    TxtReport(const QString &filename);
     virtual ~TxtReport();
 
     /**
