@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2012 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2013 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,8 +26,8 @@
 static const char ResultElementName[] = "results";
 static const char VersionAttribute[] = "version";
 
-XmlReport::XmlReport(const QString &filename, QObject * parent) :
-    Report(filename, parent)
+XmlReport::XmlReport(const QString &filename) :
+    Report(filename)
 {
 }
 
