@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2012 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2013 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@ class QObject;
 */
 class XmlReport : public Report {
 public:
-    XmlReport(const QString &filename, QObject * parent = 0);
+    XmlReport(const QString &filename);
 
     /**
      * @brief Read contents of the report file.
