@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2012 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2013 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,10 +19,7 @@
 #ifndef XML_REPORTV1_H
 #define XML_REPORTV1_H
 
-#include <QObject>
 #include <QString>
-#include <QStringList>
-#include <QFile>
 #include <QXmlStreamReader>
 #include <QXmlStreamWriter>
 #include "xmlreport.h"
@@ -38,7 +35,7 @@
 */
 class XmlReportV1 : public XmlReport {
 public:
-    XmlReportV1(const QString &filename, QObject * parent = 0);
+    XmlReportV1(const QString &filename);
     virtual ~XmlReportV1();
 
     /**
