@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2012 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2013 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,6 @@
 #include <QString>
 #include <QList>
 #include <QDir>
-#include <QFile>
 #include <QXmlStreamWriter>
 #include <QDebug>
 #include "report.h"
@@ -42,8 +41,8 @@ static const char MsgAttribute[] = "msg";
 static const char VersionAttribute[] = "version";
 static const char VerboseAttribute[] = "verbose";
 
-XmlReportV2::XmlReportV2(const QString &filename, QObject * parent) :
-    XmlReport(filename, parent),
+XmlReportV2::XmlReportV2(const QString &filename) :
+    XmlReport(filename),
     mXmlReader(NULL),
     mXmlWriter(NULL)
 {
@@ -53,27 +52,24 @@ XmlReportV2::~XmlReportV2()
 {
     delete mXmlReader;
     delete mXmlWriter;
-    Close();
 }
 
 bool XmlReportV2::Create()
 {
-    bool success = false;
     if (Report::Create()) {
         mXmlWriter = new QXmlStreamWriter(Report::GetFile());
-        success = true;
+        return true;
     }
-    return success;
+    return false;
 }
 
 bool XmlReportV2::Open()
 {
-    bool success = false;
     if (Report::Open()) {
         mXmlReader = new QXmlStreamReader(Report::GetFile());
-        success = true;
+        return true;
     }
-    return success;
+    return false;
 }
 
 void XmlReportV2::WriteHeader()
