@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2012 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2013 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -132,8 +132,9 @@ protected:
 private:
     const std::string _name;
 
-    /** disabled assignment operator */
+    /** disabled assignment operator and copy constructor */
     void operator=(const Check &);
+    Check(const Check &);
 };
 
 namespace std {
@@ -155,4 +156,3 @@ inline Check::Check(const std::string &aname)
 /// @}
 
 #endif
-
