@@ -70,7 +70,7 @@ void CheckAssignIf::assignIf()
             if (num < 0 && bitop == '|')
                 continue;
 
-            assignIfParseScope(tok, tok->tokAt(4), var->varId(), var->isLocal(), bitop, num);
+            assignIfParseScope(tok, tok->tokAt(4), var->declarationId(), var->isLocal(), bitop, num);
         }
     }
 }
@@ -100,6 +100,7 @@ bool CheckAssignIf::assignIfParseScope(const Token * const assignTok,
             return true;
         }
         if (Token::Match(tok2, "[(,] &| %varid% [,)]", varid))
+            // TODO: don't bailout if variable is passed by value
             return true;
         if (tok2->str() == "}")
             return false;
