@@ -22,6 +22,7 @@
 
 #include "checkautovariables.h"
 #include "symboldatabase.h"
+#include "checkuninitvar.h"
 
 #include <list>
 #include <string>
@@ -35,23 +36,30 @@ namespace {
 }
 
 
-bool CheckAutoVariables::isRefPtrArg(unsigned int varId)
+bool CheckAutoVariables::isPtrArg(const Token *tok)
 {
-    const Variable *var = _tokenizer->getSymbolDatabase()->getVariableFromVarId(varId);
-
-    return(var && var->isArgument() && var->isReference() && var->isPointer());
-}
-
-bool CheckAutoVariables::isPtrArg(unsigned int varId)
-{
-    const Variable *var = _tokenizer->getSymbolDatabase()->getVariableFromVarId(varId);
+    const Variable *var = tok->variable();
 
     return(var && var->isArgument() && var->isPointer());
 }
 
-bool CheckAutoVariables::isAutoVar(unsigned int varId)
+bool CheckAutoVariables::isRefPtrArg(const Token *tok)
 {
-    const Variable *var = _tokenizer->getSymbolDatabase()->getVariableFromVarId(varId);
+    const Variable *var = tok->variable();
+
+    return(var && var->isArgument() && var->isReference() && var->isPointer());
+}
+
+bool CheckAutoVariables::isNonReferenceArg(const Token *tok)
+{
+    const Variable *var = tok->variable();
+
+    return(var && var->isArgument() && !var->isReference() && (var->isPointer() || var->typeStartToken()->isStandardType() || var->type()));
+}
+
+bool CheckAutoVariables::isAutoVar(const Token *tok)
+{
+    const Variable *var = tok->variable();
 
     if (!var || !var->isLocal() || var->isStatic())
         return false;
@@ -66,43 +74,73 @@ bool CheckAutoVariables::isAutoVar(unsigned int varId)
     return true;
 }
 
-bool CheckAutoVariables::isAutoVarArray(unsigned int varId)
+bool CheckAutoVariables::isAutoVarArray(const Token *tok)
 {
-    const Variable *var = _tokenizer->getSymbolDatabase()->getVariableFromVarId(varId);
+    const Variable *var = tok->variable();
 
     return (var && var->isLocal() && !var->isStatic() && var->isArray());
 }
 
 // Verification that we really take the address of a local variable
-static bool checkRvalueExpression(const Variable* var, const Token* next)
+static bool checkRvalueExpression(const Token * const vartok)
 {
+    const Variable * const var = vartok->variable();
+    if (var == NULL)
+        return false;
+
+    const Token * const next = vartok->next();
+
+    // &a.b[0]
+    if (Token::Match(vartok, "%var% . %var% [") && !var->isPointer()) {
+        const Variable *var2 = next->next()->variable();
+        return var2 && !var2->isPointer();
+    }
+
     return((next->str() != "." || (!var->isPointer() && (!var->isClass() || var->type()))) && next->strAt(2) != ".");
 }
 
+static bool variableIsUsedInScope(const Token* start, unsigned int varId, const Scope *scope)
+{
+    for (const Token *tok = start; tok != scope->classEnd; tok = tok->next()) {
+        if (tok->varId() == varId)
+            return true;
+        if (tok->scope()->type == Scope::eFor || tok->scope()->type == Scope::eDo || tok->scope()->type == Scope::eWhile) // In case of loops, better checking would be necessary
+            return true;
+        if (Token::simpleMatch(tok, "asm ("))
+            return true;
+    }
+    return false;
+}
+
 void CheckAutoVariables::autoVariables()
 {
     const SymbolDatabase *symbolDatabase = _tokenizer->getSymbolDatabase();
 
+    const bool reportWarnings(_settings->isEnabled("warning"));
+
     const std::size_t functions = symbolDatabase->functionScopes.size();
     for (std::size_t i = 0; i < functions; ++i) {
         const Scope * scope = symbolDatabase->functionScopes[i];
         for (const Token *tok = scope->classStart; tok && tok != scope->classEnd; tok = tok->next()) {
             // Critical assignment
-            if (Token::Match(tok, "[;{}] %var% = & %var%") && isRefPtrArg(tok->next()->varId()) && isAutoVar(tok->tokAt(4)->varId())) {
-                const Variable * var = symbolDatabase->getVariableFromVarId(tok->tokAt(4)->varId());
-                if (checkRvalueExpression(var, tok->tokAt(5)))
+            if (Token::Match(tok, "[;{}] %var% = & %var%") && isRefPtrArg(tok->next()) && isAutoVar(tok->tokAt(4))) {
+                if (checkRvalueExpression(tok->tokAt(4)))
                     errorAutoVariableAssignment(tok->next(), false);
-            } else if (Token::Match(tok, "[;{}] * %var% = & %var%") && isPtrArg(tok->tokAt(2)->varId()) && isAutoVar(tok->tokAt(5)->varId())) {
-                const Variable * var = symbolDatabase->getVariableFromVarId(tok->tokAt(5)->varId());
-                if (checkRvalueExpression(var, tok->tokAt(6)))
+            } else if (Token::Match(tok, "[;{}] * %var% = & %var%") && isPtrArg(tok->tokAt(2)) && isAutoVar(tok->tokAt(5))) {
+                if (checkRvalueExpression(tok->tokAt(5)))
                     errorAutoVariableAssignment(tok->next(), false);
+            } else if (reportWarnings &&
+                       Token::Match(tok, "[;{}] %var% =") &&
+                       isNonReferenceArg(tok->next()) &&
+                       !variableIsUsedInScope(Token::findsimplematch(tok->tokAt(2), ";"), tok->next()->varId(), scope)) {
+                errorUselessAssignmentPtrArg(tok->next());
             } else if (Token::Match(tok, "[;{}] %var% . %var% = & %var%")) {
                 // TODO: check if the parameter is only changed temporarily (#2969)
                 if (_settings->inconclusive) {
-                    const Variable * var1 = symbolDatabase->getVariableFromVarId(tok->next()->varId());
+                    const Variable * var1 = tok->next()->variable();
                     if (var1 && var1->isArgument() && var1->isPointer()) {
-                        const Variable * var2 = symbolDatabase->getVariableFromVarId(tok->tokAt(6)->varId());
-                        if (isAutoVar(tok->tokAt(6)->varId()) && checkRvalueExpression(var2, tok->tokAt(7)))
+                        const Token * const var2tok = tok->tokAt(6);
+                        if (isAutoVar(var2tok) && checkRvalueExpression(var2tok))
                             errorAutoVariableAssignment(tok->next(), true);
                     }
                 }
@@ -110,42 +148,41 @@ void CheckAutoVariables::autoVariables()
             } else if (Token::Match(tok, "[;{}] %var% . %var% = %var% ;")) {
                 // TODO: check if the parameter is only changed temporarily (#2969)
                 if (_settings->inconclusive) {
-                    const Variable * var1 = symbolDatabase->getVariableFromVarId(tok->next()->varId());
+                    const Variable * var1 = tok->next()->variable();
                     if (var1 && var1->isArgument() && var1->isPointer()) {
-                        if (isAutoVarArray(tok->tokAt(5)->varId()))
+                        if (isAutoVarArray(tok->tokAt(5)))
                             errorAutoVariableAssignment(tok->next(), true);
                     }
                 }
                 tok = tok->tokAt(5);
             } else if (Token::Match(tok, "[;{}] * %var% = %var% ;")) {
-                const Variable * var1 = symbolDatabase->getVariableFromVarId(tok->tokAt(2)->varId());
+                const Variable * var1 = tok->tokAt(2)->variable();
                 if (var1 && var1->isArgument() && Token::Match(var1->nameToken()->tokAt(-3), "%type% * *")) {
-                    if (isAutoVarArray(tok->tokAt(4)->varId()))
+                    if (isAutoVarArray(tok->tokAt(4)))
                         errorAutoVariableAssignment(tok->next(), false);
                 }
                 tok = tok->tokAt(4);
-            } else if (Token::Match(tok, "[;{}] %var% [") && Token::Match(tok->linkAt(2), "] = & %var%") && isPtrArg(tok->next()->varId()) && isAutoVar(tok->linkAt(2)->tokAt(3)->varId())) {
+            } else if (Token::Match(tok, "[;{}] %var% [") && Token::Match(tok->linkAt(2), "] = & %var%") && isPtrArg(tok->next()) && isAutoVar(tok->linkAt(2)->tokAt(3))) {
                 const Token* const varTok = tok->linkAt(2)->tokAt(3);
-                const Variable * var = symbolDatabase->getVariableFromVarId(varTok->varId());
-                if (checkRvalueExpression(var, varTok->next()))
+                if (checkRvalueExpression(varTok))
                     errorAutoVariableAssignment(tok->next(), false);
             }
             // Critical return
-            else if (Token::Match(tok, "return & %var% ;") && isAutoVar(tok->tokAt(2)->varId())) {
+            else if (Token::Match(tok, "return & %var% ;") && isAutoVar(tok->tokAt(2))) {
                 errorReturnAddressToAutoVariable(tok);
             } else if (Token::Match(tok, "return & %var% [") &&
                        Token::simpleMatch(tok->linkAt(3), "] ;") &&
-                       isAutoVarArray(tok->tokAt(2)->varId())) {
+                       isAutoVarArray(tok->tokAt(2))) {
                 errorReturnAddressToAutoVariable(tok);
             } else if (Token::Match(tok, "return & %var% ;") && tok->tokAt(2)->varId()) {
-                const Variable * var1 = symbolDatabase->getVariableFromVarId(tok->tokAt(2)->varId());
+                const Variable * var1 = tok->tokAt(2)->variable();
                 if (var1 && var1->isArgument() && var1->typeEndToken()->str() != "&")
                     errorReturnAddressOfFunctionParameter(tok, tok->strAt(2));
             }
             // Invalid pointer deallocation
             else if (Token::Match(tok, "free ( %var% ) ;") || Token::Match(tok, "delete [| ]| (| %var% !![")) {
                 tok = Token::findmatch(tok->next(), "%var%");
-                if (isAutoVarArray(tok->varId()))
+                if (isAutoVarArray(tok))
                     errorInvalidDeallocation(tok);
             }
         }
@@ -171,8 +208,7 @@ void CheckAutoVariables::returnPointerToLocalArray()
             for (const Token *tok2 = scope->classStart->next(); tok2 && tok2 != scope->classEnd; tok2 = tok2->next()) {
                 // Return pointer to local array variable..
                 if (Token::Match(tok2, "return %var% ;")) {
-                    const unsigned int varid = tok2->next()->varId();
-                    if (isAutoVarArray(varid)) {
+                    if (isAutoVarArray(tok2->next())) {
                         errorReturnPointerToLocalArray(tok2);
                     }
                 }
@@ -219,10 +255,18 @@ void CheckAutoVariables::errorReturnAddressOfFunctionParameter(const Token *tok,
                 "value is invalid.");
 }
 
+void CheckAutoVariables::errorUselessAssignmentPtrArg(const Token *tok)
+{
+    reportError(tok,
+                Severity::warning,
+                "uselessAssignmentPtrArg",
+                "Assignment of function parameter has no effect outside the function.");
+}
+
 //---------------------------------------------------------------------------
 
 // return temporary?
-bool CheckAutoVariables::returnTemporary(const Token *tok, const Scope *startScope) const
+bool CheckAutoVariables::returnTemporary(const Token *tok) const
 {
     const SymbolDatabase *symbolDatabase = _tokenizer->getSymbolDatabase();
 
@@ -230,7 +274,7 @@ bool CheckAutoVariables::returnTemporary(const Token *tok, const Scope *startSco
     bool retref = false;   // is there such a function that returns a reference?
     bool retvalue = false; // is there such a function that returns a value?
 
-    const Function *function = symbolDatabase->findFunctionByNameAndArgs(tok, startScope);
+    const Function *function = tok->function();
     if (function) {
         retref = function->tokenDef->strAt(-1) == "&";
         if (!retref) {
@@ -285,10 +329,8 @@ void CheckAutoVariables::returnReference()
                 // return..
                 if (Token::Match(tok2, "return %var% ;")) {
                     // is the returned variable a local variable?
-                    const unsigned int varid1 = tok2->next()->varId();
-                    const Variable *var1 = symbolDatabase->getVariableFromVarId(varid1);
-
-                    if (isAutoVar(varid1)) {
+                    if (isAutoVar(tok2->next())) {
+                        const Variable *var1 = tok2->next()->variable();
                         // If reference variable is used, check what it references
                         if (Token::Match(var1->nameToken(), "%var% [=(]")) {
                             const Token *tok3 = var1->nameToken()->tokAt(2);
@@ -297,7 +339,7 @@ void CheckAutoVariables::returnReference()
 
                             // Only report error if variable that is referenced is
                             // a auto variable
-                            if (!isAutoVar(tok3->varId()))
+                            if (!isAutoVar(tok3))
                                 continue;
                         }
 
@@ -309,7 +351,7 @@ void CheckAutoVariables::returnReference()
                 // return reference to temporary..
                 else if (Token::Match(tok2, "return %var% (") &&
                          Token::simpleMatch(tok2->linkAt(2), ") ;")) {
-                    if (returnTemporary(tok2->next(), scope)) {
+                    if (returnTemporary(tok2->next())) {
                         // report error..
                         errorReturnTempReference(tok2);
                     }
