@@ -63,18 +63,18 @@ public:
     void returnReference();
 
 private:
-    bool isRefPtrArg(unsigned int varId);
-    bool isPtrArg(unsigned int varId);
-    bool isAutoVar(unsigned int varId);
-    bool isAutoVarArray(unsigned int varId);
+    static bool isPtrArg(const Token *tok);
+    static bool isRefPtrArg(const Token *tok);
+    static bool isNonReferenceArg(const Token *tok);
+    static bool isAutoVar(const Token *tok);
+    static bool isAutoVarArray(const Token *tok);
 
     /**
      * Returning a temporary object?
      * @param tok pointing at the "return" token
-     * @param startScope indicates the function scope to be checked
      * @return true if a temporary object is returned
      */
-    bool returnTemporary(const Token *tok, const Scope *startScope) const;
+    bool returnTemporary(const Token *tok) const;
 
     void errorReturnAddressToAutoVariable(const Token *tok);
     void errorReturnPointerToLocalArray(const Token *tok);
@@ -83,6 +83,7 @@ private:
     void errorReturnTempReference(const Token *tok);
     void errorInvalidDeallocation(const Token *tok);
     void errorReturnAddressOfFunctionParameter(const Token *tok, const std::string &varname);
+    void errorUselessAssignmentPtrArg(const Token *tok);
 
     void getErrorMessages(ErrorLogger *errorLogger, const Settings *settings) const {
         CheckAutoVariables c(0,settings,errorLogger);
@@ -93,6 +94,7 @@ private:
         c.errorReturnTempReference(0);
         c.errorInvalidDeallocation(0);
         c.errorReturnAddressOfFunctionParameter(0, "parameter");
+        c.errorUselessAssignmentPtrArg(0);
     }
 
     static std::string myName() {
@@ -105,7 +107,8 @@ private:
                "* returning a pointer to auto or temporary variable\n"
                "* assigning address of an variable to an effective parameter of a function\n"
                "* returning reference to local/temporary variable\n"
-               "* returning address of function parameter\n";
+               "* returning address of function parameter\n"
+               "* useless assignment of pointer parameter\n";
     }
 };
 /// @}
