@@ -66,7 +66,7 @@ void CheckExceptionSafety::destructors()
 
 void CheckExceptionSafety::deallocThrow()
 {
-    if (!_settings->isEnabled("style"))
+    if (!_settings->isEnabled("warning"))
         return;
 
     const SymbolDatabase* const symbolDatabase = _tokenizer->getSymbolDatabase();
@@ -89,15 +89,14 @@ void CheckExceptionSafety::deallocThrow()
                 break;
             if (!Token::Match(tok, "%var% ;"))
                 continue;
-            const unsigned int varid(tok->varId());
-            if (varid == 0)
-                continue;
 
             // we only look for global variables
-            const Variable* var = symbolDatabase->getVariableFromVarId(varid);
+            const Variable *var = tok->variable();
             if (!var || !(var->isGlobal() || var->isStatic()))
                 continue;
 
+            const unsigned int varid(tok->varId());
+
             // Token where throw occurs
             const Token *ThrowToken = 0;
 
@@ -115,7 +114,7 @@ void CheckExceptionSafety::deallocThrow()
 
                 // Variable is assigned -> Bail out
                 else if (Token::Match(tok2, "%varid% =", varid)) {
-                    if (ThrowToken) // For non-inconclusive checking, wait until we find an assignement to it. Otherwise we assume it is safe to leave a dead pointer.
+                    if (ThrowToken) // For non-inconclusive checking, wait until we find an assignment to it. Otherwise we assume it is safe to leave a dead pointer.
                         deallocThrowError(ThrowToken, tok2->str());
                     break;
                 }
@@ -172,7 +171,7 @@ void CheckExceptionSafety::checkCatchExceptionByValue()
 
         // Find a pass-by-value declaration in the catch(), excluding basic types
         // e.g. catch (std::exception err)
-        const Variable* var = symbolDatabase->getVariableFromVarId(i->classStart->tokAt(-2)->varId());
+        const Variable *var = i->classStart->tokAt(-2)->variable();
         if (var && var->isClass() && !var->isPointer() && !var->isReference())
             catchExceptionByValueError(i->classDef);
     }
