@@ -107,16 +107,16 @@ void CheckIO::checkFileUsage()
     std::size_t varListSize = symbolDatabase->getVariableListSize();
     for (std::size_t i = 1; i < varListSize; ++i) {
         const Variable* var = symbolDatabase->getVariableFromVarId(i);
-        if (!var || !var->varId() || var->isArray() || !Token::simpleMatch(var->typeStartToken(), "FILE *"))
+        if (!var || !var->declarationId() || var->isArray() || !Token::simpleMatch(var->typeStartToken(), "FILE *"))
             continue;
 
         if (var->isLocal()) {
             if (var->nameToken()->strAt(1) == "(") // initialize by calling "ctor"
-                filepointers.insert(std::make_pair(var->varId(), Filepointer(UNKNOWN)));
+                filepointers.insert(std::make_pair(var->declarationId(), Filepointer(UNKNOWN)));
             else
-                filepointers.insert(std::make_pair(var->varId(), Filepointer(CLOSED)));
+                filepointers.insert(std::make_pair(var->declarationId(), Filepointer(CLOSED)));
         } else {
-            filepointers.insert(std::make_pair(var->varId(), Filepointer(UNKNOWN)));
+            filepointers.insert(std::make_pair(var->declarationId(), Filepointer(UNKNOWN)));
             // TODO: If all fopen calls we find open the file in the same type, we can set Filepointer::mode
         }
     }
@@ -439,7 +439,27 @@ void CheckIO::checkWrongPrintfScanfArguments()
             const Token* argListTok = 0; // Points to first va_list argument
             std::string formatString;
 
-            if (Token::Match(tok, "printf|scanf|wprintf|wscanf ( %str%")) {
+            if (Token::Match(tok->next(), "( %any%")) {
+                const Token *arg = tok->tokAt(2);
+                int argnr = 1;
+                while (arg) {
+                    if (Token::Match(arg, "%str% [,)]") && _settings->library.isargformatstr(tok->str(),argnr)) {
+                        formatString = arg->str();
+                        if (arg->strAt(1) == ",")
+                            argListTok = arg->tokAt(2);
+                        else
+                            argListTok = 0;
+                        break;
+                    }
+
+                    arg = arg->nextArgument();
+                    argnr++;
+                }
+            }
+
+            if (!formatString.empty()) {
+                /* formatstring found in library */
+            } else if (Token::Match(tok, "printf|scanf|wprintf|wscanf ( %str%")) {
                 formatString = tok->strAt(2);
                 if (tok->strAt(3) == ",") {
                     argListTok = tok->tokAt(4);
@@ -482,6 +502,7 @@ void CheckIO::checkWrongPrintfScanfArguments()
             unsigned int numFormat = 0;
             bool percent = false;
             const Token* argListTok2 = argListTok;
+            std::set<unsigned int> parameterPositionsUsed;
             for (std::string::iterator i = formatString.begin(); i != formatString.end(); ++i) {
                 if (*i == '%') {
                     percent = !percent;
@@ -503,6 +524,8 @@ void CheckIO::checkWrongPrintfScanfArguments()
 
                     bool _continue = false;
                     std::string width;
+                    unsigned int parameterPosition = 0;
+                    bool hasParameterPosition = false;
                     while (i != formatString.end() && *i != ']' && !std::isalpha(*i)) {
                         if (*i == '*') {
                             if (scan)
@@ -512,8 +535,13 @@ void CheckIO::checkWrongPrintfScanfArguments()
                                 if (argListTok)
                                     argListTok = argListTok->nextArgument();
                             }
-                        } else if (std::isdigit(*i))
+                        } else if (std::isdigit(*i)) {
                             width += *i;
+                        } else if (*i == '$') {
+                            parameterPosition = static_cast<unsigned int>(std::atoi(width.c_str()));
+                            hasParameterPosition = true;
+                            width.clear();
+                        }
                         ++i;
                     }
                     if (i == formatString.end())
@@ -522,7 +550,15 @@ void CheckIO::checkWrongPrintfScanfArguments()
                         continue;
 
                     if (scan || *i != 'm') { // %m is a non-standard extension that requires no parameter on print functions.
-                        numFormat++;
+                        ++numFormat;
+
+                        // Handle parameter positions (POSIX extension) - Ticket #4900
+                        if (hasParameterPosition) {
+                            if (parameterPositionsUsed.find(parameterPosition) == parameterPositionsUsed.end())
+                                parameterPositionsUsed.insert(parameterPosition);
+                            else // Parameter already referenced, hence don't consider it a new format
+                                --numFormat;
+                        }
 
                         // Perform type checks
                         if (argListTok && Token::Match(argListTok->next(), "[,)]")) { // We can currently only check the type of arguments matching this simple pattern.
@@ -543,86 +579,145 @@ void CheckIO::checkWrongPrintfScanfArguments()
                                     }
                                 }
                             } else if (!scan && warning) {
-                                switch (*i) {
-                                case 's':
-                                    if (variableInfo && argListTok->type() != Token::eString && isKnownType(variableInfo, varTypeTok) && (!variableInfo->isPointer() && !variableInfo->isArray()))
-                                        invalidPrintfArgTypeError_s(tok, numFormat);
-                                    break;
-                                case 'n':
-                                    if ((varTypeTok && isKnownType(variableInfo, varTypeTok) && ((!variableInfo->isPointer() && !variableInfo->isArray()) || varTypeTok->strAt(-1) == "const")) || argListTok->type() == Token::eString)
-                                        invalidPrintfArgTypeError_n(tok, numFormat);
-                                    break;
-                                case 'c':
-                                case 'x':
-                                case 'X':
-                                case 'o':
-                                    if (varTypeTok && isKnownType(variableInfo, varTypeTok) && !Token::Match(varTypeTok, "bool|short|long|int|char|size_t") && !variableInfo->isPointer() && !variableInfo->isArray())
-                                        invalidPrintfArgTypeError_int(tok, numFormat, *i);
-                                    else if (argListTok->type() == Token::eString)
-                                        invalidPrintfArgTypeError_int(tok, numFormat, *i);
-                                    break;
-                                case 'd':
-                                case 'i':
-                                    if (varTypeTok && isKnownType(variableInfo, varTypeTok) && !variableInfo->isPointer() && !variableInfo->isArray()) {
-                                        if ((varTypeTok->isUnsigned() || !Token::Match(varTypeTok, "bool|short|long|int")) && varTypeTok->str() != "char")
-                                            invalidPrintfArgTypeError_sint(tok, numFormat, *i);
-                                    } else if (argListTok->type() == Token::eString)
-                                        invalidPrintfArgTypeError_sint(tok, numFormat, *i);
-                                    break;
-                                case 'u':
-                                    if (varTypeTok && isKnownType(variableInfo, varTypeTok) && !variableInfo->isPointer() && !variableInfo->isArray()) {
-                                        if ((!varTypeTok->isUnsigned() || !Token::Match(varTypeTok, "char|short|long|int|size_t")) && varTypeTok->str() != "bool")
-                                            invalidPrintfArgTypeError_uint(tok, numFormat, *i);
-                                    } else if (argListTok->type() == Token::eString)
-                                        invalidPrintfArgTypeError_uint(tok, numFormat, *i);
-                                    break;
-                                case 'p':
-                                    if (varTypeTok && isKnownType(variableInfo, varTypeTok) && !Token::Match(varTypeTok, "short|long|int|size_t") && !variableInfo->isPointer() && !variableInfo->isArray())
-                                        invalidPrintfArgTypeError_p(tok, numFormat);
-                                    else if (argListTok->type() == Token::eString)
-                                        invalidPrintfArgTypeError_p(tok, numFormat);
-                                    break;
-                                case 'e':
-                                case 'E':
-                                case 'f':
-                                case 'g':
-                                case 'G':
-                                    if (varTypeTok && ((isKnownType(variableInfo, varTypeTok) && !Token::Match(varTypeTok, "float|double")) || variableInfo->isPointer() || variableInfo->isArray()))
-                                        invalidPrintfArgTypeError_float(tok, numFormat, *i);
-                                    else if (argListTok->type() == Token::eString)
-                                        invalidPrintfArgTypeError_float(tok, numFormat, *i);
-                                    break;
-                                case 'h': // Can be 'hh' (signed char or unsigned char) or 'h' (short int or unsigned short int)
-                                case 'l': // Can be 'll' (long long int or unsigned long long int) or 'l' (long int or unsigned long int)
-                                    // If the next character is the same (which makes 'hh' or 'll') then expect another alphabetical character
-                                    if (i != formatString.end() && *(i+1) == *i) {
-                                        if (i+1 != formatString.end() && !isalpha(*(i+2))) {
-                                            std::string modifier;
-                                            modifier += *i;
-                                            modifier += *(i+1);
-                                            invalidLengthModifierError(tok, numFormat, modifier);
+                                std::string specifier;
+                                bool done = false;
+                                while (!done) {
+                                    switch (*i) {
+                                    case 's':
+                                        if (variableInfo && argListTok->type() != Token::eString && isKnownType(variableInfo, varTypeTok) && (!variableInfo->isPointer() && !variableInfo->isArray()))
+                                            invalidPrintfArgTypeError_s(tok, numFormat);
+                                        done = true;
+                                        break;
+                                    case 'n':
+                                        if ((varTypeTok && isKnownType(variableInfo, varTypeTok) && ((!variableInfo->isPointer() && !variableInfo->isArray()) || varTypeTok->strAt(-1) == "const")) || argListTok->type() == Token::eString)
+                                            invalidPrintfArgTypeError_n(tok, numFormat);
+                                        done = true;
+                                        break;
+                                    case 'c':
+                                    case 'x':
+                                    case 'X':
+                                    case 'o':
+                                        if (varTypeTok && isKnownType(variableInfo, varTypeTok) && !Token::Match(varTypeTok, "bool|short|long|int|char|size_t") && !variableInfo->isPointer() && !variableInfo->isArray()) {
+                                            specifier += *i;
+                                            invalidPrintfArgTypeError_int(tok, numFormat, specifier);
+                                        } else if (argListTok->type() == Token::eString) {
+                                            specifier += *i;
+                                            invalidPrintfArgTypeError_int(tok, numFormat, specifier);
                                         }
-                                    } else {
+                                        done = true;
+                                        break;
+                                    case 'd':
+                                    case 'i':
+                                        if (varTypeTok && isKnownType(variableInfo, varTypeTok) && !variableInfo->isPointer() && !variableInfo->isArray()) {
+                                            if ((varTypeTok->isUnsigned() || !Token::Match(varTypeTok, "bool|short|long|int")) && varTypeTok->str() != "char") {
+                                                specifier += *i;
+                                                invalidPrintfArgTypeError_sint(tok, numFormat, specifier);
+                                            }
+                                        } else if (argListTok->type() == Token::eString) {
+                                            specifier += *i;
+                                            invalidPrintfArgTypeError_sint(tok, numFormat, specifier);
+                                        }
+                                        done = true;
+                                        break;
+                                    case 'u':
+                                        if (varTypeTok && isKnownType(variableInfo, varTypeTok) && !variableInfo->isPointer() && !variableInfo->isArray()) {
+                                            if ((!varTypeTok->isUnsigned() || !Token::Match(varTypeTok, "char|short|long|int|size_t")) && varTypeTok->str() != "bool") {
+                                                specifier += *i;
+                                                invalidPrintfArgTypeError_uint(tok, numFormat, specifier);
+                                            }
+                                        } else if (argListTok->type() == Token::eString) {
+                                            specifier += *i;
+                                            invalidPrintfArgTypeError_uint(tok, numFormat, specifier);
+                                        }
+                                        done = true;
+                                        break;
+                                    case 'p':
+                                        if (varTypeTok && isKnownType(variableInfo, varTypeTok) && !Token::Match(varTypeTok, "short|long|int|size_t") && !variableInfo->isPointer() && !variableInfo->isArray())
+                                            invalidPrintfArgTypeError_p(tok, numFormat);
+                                        else if (argListTok->type() == Token::eString)
+                                            invalidPrintfArgTypeError_p(tok, numFormat);
+                                        done = true;
+                                        break;
+                                    case 'e':
+                                    case 'E':
+                                    case 'f':
+                                    case 'g':
+                                    case 'G':
+                                        if (varTypeTok && ((isKnownType(variableInfo, varTypeTok) && !Token::Match(varTypeTok, "float|double")) || variableInfo->isPointer() || variableInfo->isArray())) {
+                                            specifier += *i;
+                                            invalidPrintfArgTypeError_float(tok, numFormat, specifier);
+                                        } else if (argListTok->type() == Token::eString) {
+                                            specifier += *i;
+                                            invalidPrintfArgTypeError_float(tok, numFormat, specifier);
+                                        }
+                                        done = true;
+                                        break;
+                                    case 'h': // Can be 'hh' (signed char or unsigned char) or 'h' (short int or unsigned short int)
+                                    case 'l': // Can be 'll' (long long int or unsigned long long int) or 'l' (long int or unsigned long int)
+                                        // If the next character is the same (which makes 'hh' or 'll') then expect another alphabetical character
+                                        if (i != formatString.end() && *(i+1) == *i) {
+                                            if (i+1 != formatString.end()) {
+                                                if (!isalpha(*(i+2))) {
+                                                    std::string modifier;
+                                                    modifier += *i;
+                                                    modifier += *(i+1);
+                                                    invalidLengthModifierError(tok, numFormat, modifier);
+                                                    done = true;
+                                                } else {
+                                                    specifier = *i++;
+                                                    specifier += *i++;
+                                                }
+                                            } else {
+                                                done = true;
+                                            }
+                                        } else {
+                                            if (i != formatString.end()) {
+                                                if (!isalpha(*(i+1))) {
+                                                    std::string modifier;
+                                                    modifier += *i;
+                                                    invalidLengthModifierError(tok, numFormat, modifier);
+                                                    done = true;
+                                                } else {
+                                                    specifier = *i++;
+                                                }
+                                            } else {
+                                                done = true;
+                                            }
+                                        }
+                                        break;
+                                    case 'I': // Microsoft extension: I for size_t and ptrdiff_t, I32 for __int32, and I64 for __int64
+                                        if (i != formatString.end()) {
+                                            if (isalpha(*(i+1))) {
+                                                specifier = *i++;
+                                            } else if (*(i+1) == '3' && *(i+2) == '2' && isalpha(*(i+3))) {
+                                                specifier = *i++;
+                                                specifier += *i++;
+                                                specifier += *i++;
+                                            } else if (*(i+1) == '6' && *(i+2) == '4' && isalpha(*(i+3))) {
+                                                specifier = *i++;
+                                                specifier += *i++;
+                                                specifier += *i++;
+                                            }
+                                        }
+                                        break;
+                                    case 'j': // intmax_t or uintmax_t
+                                    case 'z': // size_t
+                                    case 't': // ptrdiff_t
+                                    case 'L': // long double
+                                        // Expect an alphabetical character after these specifiers
                                         if (i != formatString.end() && !isalpha(*(i+1))) {
                                             std::string modifier;
                                             modifier += *i;
                                             invalidLengthModifierError(tok, numFormat, modifier);
+                                            done = true;
+                                        } else {
+                                            specifier = *i++;
                                         }
+                                        break;
+                                    default:
+                                        done = true;
+                                        break;
                                     }
-                                    break;
-                                case 'j': // intmax_t or uintmax_t
-                                case 'z': // size_t
-                                case 't': // ptrdiff_t
-                                case 'L': // long double
-                                    // Expect an alphabetical character after these specifiers
-                                    if (i != formatString.end() && !isalpha(*(i+1))) {
-                                        std::string modifier;
-                                        modifier += *i;
-                                        invalidLengthModifierError(tok, numFormat, modifier);
-                                    }
-                                    break;
-                                default:
-                                    break;
                                 }
                             }
                         }
@@ -640,6 +735,12 @@ void CheckIO::checkWrongPrintfScanfArguments()
                 argListTok2 = argListTok2->nextArgument(); // Find next argument
             }
 
+            // Check that all parameter positions reference an actual parameter
+            for (std::set<unsigned int>::const_iterator it = parameterPositionsUsed.begin() ; it != parameterPositionsUsed.end() ; ++it) {
+                if (((*it == 0) || (*it > numFormat)) && _settings->isEnabled("warning"))
+                    wrongPrintfScanfPosixParameterPositionError(tok, tok->str(), *it, numFormat);
+            }
+
             // Mismatching number of parameters => warning
             if (numFormat != numFunction)
                 wrongPrintfScanfArgumentsError(tok, tok->str(), numFormat, numFunction);
@@ -668,6 +769,19 @@ void CheckIO::wrongPrintfScanfArgumentsError(const Token* tok,
     reportError(tok, severity, "wrongPrintfScanfArgNum", errmsg.str());
 }
 
+void CheckIO::wrongPrintfScanfPosixParameterPositionError(const Token* tok, const std::string& functionName,
+        unsigned int index, unsigned int numFunction)
+{
+    std::ostringstream errmsg;
+    errmsg << functionName << ": ";
+    if (index == 0) {
+        errmsg << "parameter positions start at 1, not 0";
+    } else {
+        errmsg << "referencing parameter " << index << " while " << numFunction << " arguments given";
+    }
+    reportError(tok, Severity::warning, "wrongPrintfScanfParameterPositionError", errmsg.str());
+}
+
 void CheckIO::invalidScanfArgTypeError(const Token* tok, const std::string &functionName, unsigned int numFormat)
 {
     std::ostringstream errmsg;
@@ -692,31 +806,31 @@ void CheckIO::invalidPrintfArgTypeError_p(const Token* tok, unsigned int numForm
     errmsg << "%p in format string (no. " << numFormat << ") requires an address given in the argument list.";
     reportError(tok, Severity::warning, "invalidPrintfArgType_p", errmsg.str());
 }
-void CheckIO::invalidPrintfArgTypeError_int(const Token* tok, unsigned int numFormat, char c)
+void CheckIO::invalidPrintfArgTypeError_int(const Token* tok, unsigned int numFormat, const std::string& specifier)
 {
     std::ostringstream errmsg;
-    errmsg << "%" << c << " in format string (no. " << numFormat << ") requires an integer given in the argument list.";
+    errmsg << "%" << specifier << " in format string (no. " << numFormat << ") requires an integer given in the argument list.";
     reportError(tok, Severity::warning, "invalidPrintfArgType_int", errmsg.str());
 }
-void CheckIO::invalidPrintfArgTypeError_uint(const Token* tok, unsigned int numFormat, char c)
+void CheckIO::invalidPrintfArgTypeError_uint(const Token* tok, unsigned int numFormat, const std::string& specifier)
 {
     std::ostringstream errmsg;
-    errmsg << "%" << c << " in format string (no. " << numFormat << ") requires an unsigned integer given in the argument list.";
+    errmsg << "%" << specifier << " in format string (no. " << numFormat << ") requires an unsigned integer given in the argument list.";
     reportError(tok, Severity::warning, "invalidPrintfArgType_uint", errmsg.str());
 }
-void CheckIO::invalidPrintfArgTypeError_sint(const Token* tok, unsigned int numFormat, char c)
+void CheckIO::invalidPrintfArgTypeError_sint(const Token* tok, unsigned int numFormat, const std::string& specifier)
 {
     std::ostringstream errmsg;
-    errmsg << "%" << c << " in format string (no. " << numFormat << ") requires a signed integer given in the argument list.";
+    errmsg << "%" << specifier << " in format string (no. " << numFormat << ") requires a signed integer given in the argument list.";
     reportError(tok, Severity::warning, "invalidPrintfArgType_sint", errmsg.str());
 }
-void CheckIO::invalidPrintfArgTypeError_float(const Token* tok, unsigned int numFormat, char c)
+void CheckIO::invalidPrintfArgTypeError_float(const Token* tok, unsigned int numFormat, const std::string& specifier)
 {
     std::ostringstream errmsg;
-    errmsg << "%" << c << " in format string (no. " << numFormat << ") requires a floating point number given in the argument list.";
+    errmsg << "%" << specifier << " in format string (no. " << numFormat << ") requires a floating point number given in the argument list.";
     reportError(tok, Severity::warning, "invalidPrintfArgType_float", errmsg.str());
 }
-void CheckIO::invalidLengthModifierError(const Token* tok, unsigned int numFormat, std::string& modifier)
+void CheckIO::invalidLengthModifierError(const Token* tok, unsigned int numFormat, const std::string& modifier)
 {
     std::ostringstream errmsg;
     errmsg << "'" << modifier << "' in format string (no. " << numFormat << ") is a length modifier and cannot be used without a conversion specifier.";
