@@ -63,11 +63,13 @@ public:
      * @brief parse a function call and extract information about variable usage
      * @param tok first token
      * @param var variables that the function read / write.
+     * @param library --library files data
      * @param value 0 => invalid with null pointers as parameter.
      *              non-zero => invalid with uninitialized data.
      */
     static void parseFunctionCall(const Token &tok,
                                   std::list<const Token *> &var,
+                                  const Library *library,
                                   unsigned char value);
 
     /**
@@ -155,7 +157,7 @@ private:
     /**
      * @brief Removes any variable that may be assigned from pointerArgs.
      */
-    void removeAssignedVarFromSet(const Token* tok, std::set<unsigned int>& pointerArgs);
+    static void removeAssignedVarFromSet(const Token* tok, std::set<unsigned int>& pointerArgs);
 
     /**
      * @brief Investigate if function call can make pointer null. If
