@@ -72,6 +72,8 @@ public:
         checkOther.checkIncompleteArrayFill();
         checkOther.checkSuspiciousStringCompare();
         checkOther.checkVarFuncNullUB();
+        checkOther.checkNanInArithmeticExpression();
+        checkOther.checkCommaSeparatedReturn();
     }
 
     /** @brief Run checks against the simplified token list */
@@ -143,6 +145,9 @@ public:
     void checkVariableScope();
     static bool checkInnerScope(const Token *tok, const Variable* var, bool& used);
 
+    /** @brief %Check for comma separated statements in return */
+    void checkCommaSeparatedReturn();
+
     /** @brief %Check for constant function parameter */
     void checkConstantFunctionParameter();
 
@@ -158,6 +163,9 @@ public:
     /** @brief %Check zero division*/
     void checkZeroDivision();
 
+    /** @brief Check for NaN (not-a-number) in an arithmetic expression */
+    void checkNanInArithmeticExpression();
+
     /** @brief %Check for parameters given to math function that do not make sense*/
     void checkMathFunctions();
 
@@ -278,6 +286,7 @@ private:
     void variableScopeError(const Token *tok, const std::string &varname);
     void strPlusCharError(const Token *tok);
     void zerodivError(const Token *tok);
+    void nanInArithmeticExpressionError(const Token *tok);
     void mathfunctionCallError(const Token *tok, const unsigned int numParam = 1);
     void cctypefunctionCallError(const Token *tok, const std::string &functionName, const std::string &value);
     void redundantAssignmentError(const Token *tok1, const Token* tok2, const std::string& var, bool inconclusive);
@@ -314,6 +323,7 @@ private:
     void redundantCopyError(const Token *tok, const std::string &varname);
     void incompleteArrayFillError(const Token* tok, const std::string& buffer, const std::string& function, bool boolean);
     void varFuncNullUBError(const Token *tok);
+    void commaSeparatedReturnError(const Token *tok);
 
     void getErrorMessages(ErrorLogger *errorLogger, const Settings *settings) const {
         CheckOther c(0, settings, errorLogger);
@@ -377,6 +387,8 @@ private:
         c.moduloAlwaysTrueFalseError(0, "1");
         c.incompleteArrayFillError(0, "buffer", "memset", false);
         c.varFuncNullUBError(0);
+        c.nanInArithmeticExpressionError(0);
+        c.commaSeparatedReturnError(0);
     }
 
     static std::string myName() {
@@ -438,7 +450,9 @@ private:
                "* Comparisons of modulo results that are always true/false.\n"
                "* Array filled incompletely using memset/memcpy/memmove.\n"
                "* redundant get and set function of user id (--std=posix).\n"
-               "* Passing NULL pointer to function with variable number of arguments leads to UB on some platforms.\n";
+               "* Passing NULL pointer to function with variable number of arguments leads to UB on some platforms.\n"
+               "* NaN (not a number) value used in arithmetic expression.\n"
+               "* comma in return statement (the comma can easily be misread as a semicolon).\n";
     }
 
     void checkExpressionRange(const std::list<const Function*> &constFunctions,
