@@ -43,37 +43,44 @@ void CheckPostfixOperator::postfixOperator()
     for (std::size_t i = 0; i < functions; ++i) {
         const Scope * scope = symbolDatabase->functionScopes[i];
         for (const Token* tok = scope->classStart->next(); tok != scope->classEnd; tok = tok->next()) {
-            if (tok->type() == Token::eIncDecOp) {
-                bool result = false;
-                if (Token::Match(tok->tokAt(-2), ";|{|}") && Token::Match(tok->next(), ";|)|,")) {
+            bool result = false;
+            const Variable *var = tok->variable();
+            if (var && Token::Match(tok, "%var% ++|--")) {
+                if (Token::Match(tok->previous(), ";|{|}") && Token::Match(tok->tokAt(2), ";|,|)")) {
                     result = true;
-                } else if (tok->strAt(-2) == ",") {
-                    int ii(1);
-                    while (tok->strAt(ii) != ")" && tok->tokAt(ii) != 0) {
-                        if (tok->strAt(ii) == ";") {
+                } else if (tok->strAt(-1) == ",") {
+                    for (const Token* tok2 = tok->tokAt(2); tok2 != 0 && tok2->str() != ")"; tok2 = tok2->next()) {
+                        if (tok2->str() == ";") {
                             result = true;
                             break;
-                        }
-                        ++ii;
+                        } else if (tok2->str() == "(")
+                            tok2 = tok2->link();
+                    }
+                } else if (tok->strAt(-1) == ".") {
+                    for (const Token* tok2 = tok->tokAt(-2); tok2 != 0; tok2 = tok2->previous()) {
+                        if (Token::Match(tok2, ";|{|}")) {
+                            result = true;
+                            break;
+                        } else if (Token::Match(tok2, ")|]|>") && tok2->link())
+                            tok2 = tok2->link();
+                        else if (tok2->isAssignmentOp() || Token::Match(tok2, "(|["))
+                            break;
                     }
-                } else if (tok->strAt(-2) == "<<" && tok->strAt(1) == "<<") {
-                    result = true;
                 }
+            }
 
-                if (result && tok->previous()->varId()) {
-                    const Variable *var = symbolDatabase->getVariableFromVarId(tok->previous()->varId());
-                    if (!var || var->isPointer() || var->isArray() || var->isReference())
-                        continue;
+            if (result) {
+                if (var->isPointer() || var->isArray())
+                    continue;
 
-                    const Token *decltok = var->nameToken();
+                const Token *decltok = var->nameToken();
 
-                    if (Token::Match(decltok->previous(), "iterator|const_iterator|reverse_iterator|const_reverse_iterator")) {
-                        // the variable is an iterator
-                        postfixOperatorError(tok);
-                    } else if (var->type()) {
-                        // the variable is an instance of class
-                        postfixOperatorError(tok);
-                    }
+                if (Token::Match(decltok->previous(), "iterator|const_iterator|reverse_iterator|const_reverse_iterator")) {
+                    // the variable is an iterator
+                    postfixOperatorError(tok);
+                } else if (var->type()) {
+                    // the variable is an instance of class
+                    postfixOperatorError(tok);
                 }
             }
         }
