@@ -20,6 +20,8 @@
 //---------------------------------------------------------------------------
 #include "checksizeof.h"
 #include "symboldatabase.h"
+#include <algorithm>
+#include <cctype>
 //---------------------------------------------------------------------------
 
 // Register this check class (by creating a static instance of it)
@@ -278,3 +280,75 @@ void CheckSizeof::divideSizeofError(const Token *tok)
                 "Division of result of sizeof() on pointer type. sizeof() returns the size of the pointer, "
                 "not the size of the memory area it points to.", true);
 }
+
+void CheckSizeof::sizeofVoid()
+{
+    if (!_settings->isEnabled("portability"))
+        return;
+
+    for (const Token *tok = _tokenizer->tokens(); tok; tok = tok->next()) {
+        if (Token::simpleMatch(tok, "sizeof ( )")) { // "sizeof(void)" gets simplified to sizeof ( )
+            sizeofVoidError(tok);
+        } else if (Token::Match(tok, "sizeof ( * %var% )") && tok->tokAt(3)->variable() &&
+                   (Token::Match(tok->tokAt(3)->variable()->typeStartToken(), "void * !!*")) &&
+                   (!tok->tokAt(3)->variable()->isArray())) { // sizeof(*p) where p is of type "void*"
+            sizeofDereferencedVoidPointerError(tok, tok->strAt(3));
+        } else if (Token::Match(tok, "%var% +|-|++|--") ||
+                   Token::Match(tok, "+|-|++|-- %var%")) { // Arithmetic operations on variable of type "void*"
+            int index = (tok->isName()) ? 0 : 1;
+            const Variable* var = tok->tokAt(index)->variable();
+            if (var && Token::Match(var->typeStartToken(), "void *")) {
+                std::string varname = tok->str();
+                // In case this 'void *' var is a member then go back to the main object
+                const Token* tok2 = tok->tokAt(index);
+                if (index == 0) {
+                    bool isMember = false;
+                    while (Token::Match(tok2->previous(), ".")) {
+                        isMember = true;
+                        if (Token::Match(tok2->tokAt(-2), ")"))
+                            tok2 = tok2->tokAt(-2)->link();
+                        else if (Token::Match(tok2->tokAt(-2), "]"))
+                            tok2 = tok2->tokAt(-2)->link()->previous();
+                        else
+                            tok2 = tok2->tokAt(-2);
+                    }
+                    if (isMember) {
+                        // Get 'struct.member' complete name (without spaces)
+                        varname = tok2->stringifyList(tok->tokAt(index)->next());
+                        varname.erase(remove_if(varname.begin(), varname.end(),
+                                                static_cast<int (*)(int)>(std::isspace)), varname.end());
+                    }
+                }
+                // Check for cast on operations with '+|-'
+                if (Token::Match(tok, "%var% +|-")) {
+                    // Check for cast expression
+                    if (Token::Match(tok2->previous(), ")") && !Token::Match(tok2->previous()->link(), "( const| void *"))
+                        continue;
+                }
+                arithOperationsOnVoidPointerError(tok, varname,
+                                                  var->typeStartToken()->stringifyList(var->typeEndToken()->next()));
+            }
+        }
+    }
+}
+
+void CheckSizeof::sizeofVoidError(const Token *tok)
+{
+    const std::string message = "Behaviour of 'sizeof(void)' is not covered by the ISO C standard.";
+    const std::string verbose = message + " A value for 'sizeof(void)' is defined only as part of a GNU C extension, which defines 'sizeof(void)' to be 1.";
+    reportError(tok, Severity::portability, "sizeofVoid", message + "\n" + verbose);
+}
+
+void CheckSizeof::sizeofDereferencedVoidPointerError(const Token *tok, const std::string &varname)
+{
+    const std::string message = "'*" + varname + "' is of type 'void', the behaviour of 'sizeof(void)' is not covered by the ISO C standard.";
+    const std::string verbose = message + " A value for 'sizeof(void)' is defined only as part of a GNU C extension, which defines 'sizeof(void)' to be 1.";
+    reportError(tok, Severity::portability, "sizeofDereferencedVoidPointer", message + "\n" + verbose);
+}
+
+void CheckSizeof::arithOperationsOnVoidPointerError(const Token* tok, const std::string &varname, const std::string &vartype)
+{
+    const std::string message = "'" + varname + "' is of type '" + vartype + "'. When using void pointers in calculations, the behaviour is undefined.";
+    const std::string verbose = message + " Arithmetic operations on 'void *' is a GNU C extension, which defines the 'sizeof(void)' to be 1.";
+    reportError(tok, Severity::portability, "arithOperationsOnVoidPointer", message + "\n" + verbose);
+}
