@@ -39,21 +39,14 @@ class Variable;
 class CPPCHECKLIB CheckUninitVar : public Check {
 public:
     /** @brief This constructor is used when registering the CheckUninitVar */
-    CheckUninitVar() : Check(myName())
+    CheckUninitVar() : Check(myName()), testrunner(false)
     { }
 
     /** @brief This constructor is used when running checks. */
     CheckUninitVar(const Tokenizer *tokenizer, const Settings *settings, ErrorLogger *errorLogger)
-        : Check(myName(), tokenizer, settings, errorLogger)
+        : Check(myName(), tokenizer, settings, errorLogger), testrunner(false)
     { }
 
-    /** @brief Run checks against the normal token list */
-    void runChecks(const Tokenizer *tokenizer, const Settings *settings, ErrorLogger *errorLogger) {
-        (void)tokenizer;
-        (void)settings;
-        (void)errorLogger;
-    }
-
     /** @brief Run checks against the simplified token list */
     void runSimplifiedChecks(const Tokenizer *tokenizer, const Settings *settings, ErrorLogger *errorLogger) {
         CheckUninitVar checkUninitVar(tokenizer, settings, errorLogger);
@@ -64,10 +57,13 @@ public:
     /** Check for uninitialized variables */
     void check();
     void checkScope(const Scope* scope);
-    bool checkScopeForVariable(const Scope* scope, const Token *tok, const Variable& var, bool * const possibleInit, bool * const noreturn);
-    bool checkIfForWhileHead(const Scope *scope, const Token *startparanthesis, const Variable& var, bool suppressErrors, bool isuninit);
-    bool isVariableUsage(const Scope* scope, const Token *vartok, bool ispointer) const;
-
+    bool checkScopeForVariable(const Scope* scope, const Token *tok, const Variable& var, bool * const possibleInit, bool * const noreturn, const std::string &membervar);
+    bool checkIfForWhileHead(const Token *startparentheses, const Variable& var, bool suppressErrors, bool isuninit, const std::string &membervar);
+    bool checkLoopBody(const Token *tok, const Variable& var, const std::string &membervar, const bool suppressErrors);
+    void checkRhs(const Token *tok, const Variable &var, const std::string &membervar);
+    static bool isVariableUsage(const Token *vartok, bool ispointer, bool cpp);
+    static bool isMemberVariableAssignment(const Token *tok, const std::string &membervar);
+    bool isMemberVariableUsage(const Token *tok, bool isPointer, const std::string &membervar) const;
 
     /**
      * @brief Uninitialized variables: analyse functions to see how they work with uninitialized variables
@@ -85,6 +81,10 @@ public:
     void uninitstringError(const Token *tok, const std::string &varname, bool strncpy_);
     void uninitdataError(const Token *tok, const std::string &varname);
     void uninitvarError(const Token *tok, const std::string &varname);
+    void uninitStructMemberError(const Token *tok, const std::string &membername);
+
+    /** testrunner: (don't abort() when assertion fails, just write error message) */
+    bool testrunner;
 
 private:
     void getErrorMessages(ErrorLogger *errorLogger, const Settings *settings) const {
@@ -94,6 +94,7 @@ private:
         c.uninitstringError(0, "varname", true);
         c.uninitdataError(0, "varname");
         c.uninitvarError(0, "varname");
+        c.uninitStructMemberError(0, "a.b");
     }
 
     static std::string myName() {
