@@ -67,10 +67,8 @@ void CheckUnusedFunctions::parseTokens(const Tokenizer &tokenizer)
         tok = funcname->linkAt(1);
 
         // Check that ") {" is found..
-        if (! Token::simpleMatch(tok, ") {") &&
-            ! Token::simpleMatch(tok, ") const {") &&
-            ! Token::simpleMatch(tok, ") const throw ( ) {") &&
-            ! Token::simpleMatch(tok, ") throw ( ) {"))
+        if (! Token::Match(tok, ") const| {") &&
+            ! Token::Match(tok, ") const| throw ( ) {"))
             funcname = 0;
 
         if (funcname) {
@@ -92,7 +90,21 @@ void CheckUnusedFunctions::parseTokens(const Tokenizer &tokenizer)
     }
 
     // Function usage..
+    const Token *scopeEnd = NULL;
     for (const Token *tok = tokenizer.tokens(); tok; tok = tok->next()) {
+        if (scopeEnd == NULL) {
+            if (!Token::Match(tok, ")|= const| {"))
+                continue;
+            scopeEnd = tok;
+            while (scopeEnd->str() != "{")
+                scopeEnd = scopeEnd->next();
+            scopeEnd = scopeEnd->link();
+        } else if (tok == scopeEnd) {
+            scopeEnd = NULL;
+            continue;
+        }
+
+
         const Token *funcname = 0;
 
         if (Token::Match(tok->next(), "%var% (")) {
@@ -115,9 +127,9 @@ void CheckUnusedFunctions::parseTokens(const Tokenizer &tokenizer)
         else
             continue;
 
-        // funcname ( => Assert that the end parenthesis isn't followed by {
+        // funcname ( => Assert that the end parentheses isn't followed by {
         if (Token::Match(funcname, "%var% (")) {
-            if (Token::Match(funcname->linkAt(1), ") const|{"))
+            if (Token::Match(funcname->linkAt(1), ") const|throw|{"))
                 funcname = NULL;
         }
 
