@@ -148,6 +148,13 @@ private:
     /** @brief Check file */
     void checkFile(const std::string &code, const char FileName[]);
 
+    /**
+     * @brief Execute rules, if any
+     * @param tokenlist token list to use (normal / simple)
+     * @param tokenizer tokenizer
+     */
+    void executeRules(const std::string &tokenlist, const Tokenizer &tokenizer);
+
     /**
      * @brief Errors and warnings are directed here.
      *
