@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2012 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2013 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,6 +32,13 @@ class TokenList;
 /// @addtogroup Core
 /// @{
 
+/** @brief Simple container to be thrown when internal error is detected. */
+struct InternalError {
+    InternalError(const Token *tok, const std::string &errorMsg);
+    const Token *token;
+    std::string errorMessage;
+};
+
 /** @brief enum class for severity. Used when reporting errors. */
 class CPPCHECKLIB Severity {
 public:
@@ -109,7 +116,7 @@ public:
         case debug:
             return "debug";
         };
-        return "???";
+        throw InternalError(NULL, "Unknown severity");
     }
     static SeverityType fromString(const std::string &severity) {
         if (severity.empty())
@@ -276,7 +283,7 @@ public:
      * @param stage for example preprocess / tokenize / simplify / check
      * @param value progress value (0-100)
      */
-    virtual void reportProgress(const std::string &filename, const char stage[], const unsigned int value) {
+    virtual void reportProgress(const std::string &filename, const char stage[], const std::size_t value) {
         (void)filename;
         (void)stage;
         (void)value;
@@ -299,13 +306,6 @@ public:
     static std::string callStackToString(const std::list<ErrorLogger::ErrorMessage::FileLocation> &callStack);
 };
 
-/** @brief Simple container to be thrown when internal error is detected. */
-struct InternalError {
-    InternalError(const Token *tok, const std::string &errorMsg);
-    const Token *token;
-    std::string errorMessage;
-};
-
 /// @}
 
 #endif
