@@ -288,6 +288,8 @@ std::string MathLib::divide(const std::string &first, const std::string &second)
         if (b == 0)
             throw InternalError(0, "Internal Error: Division by zero");
         return longToString(toLongNumber(first) / b);
+    } else if (second == "0.0") {
+        return "inf.0";
     }
     return doubleToString(toDoubleNumber(first) / toDoubleNumber(second));
 }
@@ -368,7 +370,7 @@ std::string MathLib::abs(const std::string &tok)
 bool MathLib::isEqual(const std::string &first, const std::string &second)
 {
     // this conversion is needed for formatting
-    // e.g. if first=0.1 and second=1.0E-1, the direct comparison of the strings whould fail
+    // e.g. if first=0.1 and second=1.0E-1, the direct comparison of the strings would fail
     return doubleToString(toDoubleNumber(first)) == doubleToString(toDoubleNumber(second));
 }
 
