@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2012 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2013 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,23 +34,16 @@ public:
     typedef long long bigint;
 
     static bigint toLongNumber(const std::string & str);
+    static std::string longToString(const bigint value);
     static double toDoubleNumber(const std::string & str);
-
-    template<typename T>
-    static std::string toString(const T &d) {
-        std::ostringstream result;
-        result.precision(8);
-        result << d;
-        if (isNullValue(result.str()))
-            return std::string("0");
-        return result.str();
-    }
+    static std::string doubleToString(const double value);
 
     static bool isInt(const std::string & str);
     static bool isFloat(const std::string &str);
     static bool isNegative(const std::string &str);
     static bool isHex(const std::string& str);
     static bool isOct(const std::string& str);
+    static bool isBin(const std::string& str);
 
     static std::string add(const std::string & first, const std::string & second);
     static std::string subtract(const std::string & first, const std::string & second);
