@@ -62,7 +62,7 @@ public:
      * @param istr The (file/string) stream to read from.
      * @param result The map that will get the results
      * @param filename The name of the file to check e.g. "src/main.cpp"
-     * @param includePaths List of paths where incude files should be searched from,
+     * @param includePaths List of paths where include files should be searched from,
      * single path can be e.g. in format "include/".
      * There must be a path separator at the end. Default parameter is empty list.
      * Note that if path from given filename is also extracted and that is used as
@@ -81,7 +81,7 @@ public:
      * @param resultConfigurations List of configurations. Pass these one by one
      * to getcode() with processedFile.
      * @param filename The name of the file to check e.g. "src/main.cpp"
-     * @param includePaths List of paths where incude files should be searched from,
+     * @param includePaths List of paths where include files should be searched from,
      * single path can be e.g. in format "include/".
      * There must be a path separator at the end. Default parameter is empty list.
      * Note that if path from given filename is also extracted and that is used as
@@ -122,7 +122,7 @@ public:
      * @return true => configuration is valid
      */
     bool validateCfg(const std::string &code, const std::string &cfg);
-    void validateCfgError(const std::string &cfg);
+    void validateCfgError(const std::string &cfg, const std::string &macro);
 
     void handleUndef(std::list<std::string> &configurations) const;
 
@@ -142,7 +142,7 @@ public:
      * @param str The string to be converted
      * @return The replaced string
      */
-    static std::string replaceIfDefined(const std::string &str);
+    std::string replaceIfDefined(const std::string &str) const;
 
     /**
      * expand macros in code. ifdefs etc are ignored so the code must be a single configuration
@@ -202,15 +202,15 @@ private:
      */
     static std::string removeSpaceNearNL(const std::string &str);
 
+    static std::string getdef(std::string line, bool def);
+
+public:
+
     /**
      * Get all possible configurations sorted in alphabetical order.
      * By looking at the ifdefs and ifndefs in filedata
      */
-    std::list<std::string> getcfgs(const std::string &filedata, const std::string &filename);
-
-    static std::string getdef(std::string line, bool def);
-
-public:
+    std::list<std::string> getcfgs(const std::string &filedata, const std::string &filename, const std::map<std::string, std::string> &defs);
 
     /**
      * Remove asm(...) from a string
@@ -244,7 +244,7 @@ public:
     }
 
 private:
-    void missingInclude(const std::string &filename, unsigned int linenr, const std::string &header, bool userheader);
+    void missingInclude(const std::string &filename, unsigned int linenr, const std::string &header, HeaderTypes headerType);
 
     void error(const std::string &filename, unsigned int linenr, const std::string &msg);
 
@@ -253,7 +253,7 @@ private:
      * file
      * @param code The source code to modify
      * @param filePath Relative path to file to check e.g. "src/main.cpp"
-     * @param includePaths List of paths where incude files should be searched from,
+     * @param includePaths List of paths where include files should be searched from,
      * single path can be e.g. in format "include/".
      * There must be a path separator at the end. Default parameter is empty list.
      * Note that if path from given filename is also extracted and that is used as
