@@ -39,7 +39,8 @@ Settings::Settings()
       _maxConfigs(12),
       enforcedLang(None),
       reportProgress(false),
-      checkConfiguration(false)
+      checkConfiguration(false),
+      checkLibrary(false)
 {
     // This assumes the code you are checking is for the same architecture this is compiled on.
 #if defined(_WIN64)
@@ -75,6 +76,7 @@ std::string Settings::addEnabled(const std::string &str)
 
     static std::set<std::string> id;
     if (id.empty()) {
+        id.insert("warning");
         id.insert("style");
         id.insert("performance");
         id.insert("portability");
