@@ -24,6 +24,7 @@
 #include <string>
 #include <set>
 #include "config.h"
+#include "library.h"
 #include "suppressions.h"
 #include "standards.h"
 
@@ -174,14 +175,19 @@ public:
     /** @brief --report-progress */
     bool reportProgress;
 
+    /** Library (--library) */
+    Library library;
+
     /** Rule */
     class CPPCHECKLIB Rule {
     public:
         Rule()
-            : id("rule") // default id
+            : tokenlist("simple") // use simple tokenlist
+            , id("rule")          // default id
             , severity("style") { // default severity
         }
 
+        std::string tokenlist;
         std::string pattern;
         std::string id;
         std::string severity;
@@ -196,6 +202,9 @@ public:
     /** Is the 'configuration checking' wanted? */
     bool checkConfiguration;
 
+    /** Check for incomplete info in library files? */
+    bool checkLibrary;
+
     /** Struct contains standards settings */
     Standards standards;
 
