@@ -87,7 +87,7 @@ std::string Suppressions::addSuppressionLine(const std::string &line)
     }
 
     // We could perhaps check if the id is valid and return error if it is not
-    const std::string errmsg(addSuppression(id, file, lineNumber));
+    const std::string errmsg(addSuppression(id, Path::fromNativeSeparators(file), lineNumber));
     if (!errmsg.empty())
         return errmsg;
 
@@ -139,7 +139,7 @@ bool Suppressions::FileMatcher::match(const std::string &pattern, const std::str
             return true;
         }
 
-        // If there are no other paths to tray, then fail
+        // If there are no other paths to try, then fail
         if (backtrack.empty()) {
             return false;
         }
@@ -223,8 +223,13 @@ std::string Suppressions::addSuppression(const std::string &errorId, const std::
         return "Failed to add suppression. No id.";
     }
     if (errorId != "*") {
+        // Support "stlBoundries", as that was the name of the errorId until v1.59.
+        if (errorId == "stlBoundries") {
+            return _suppressions["stlBoundaries"].addFile(file, line);
+        }
+
         for (std::string::size_type pos = 0; pos < errorId.length(); ++pos) {
-            if (errorId[pos] < 0 || (!std::isalnum(errorId[pos]) &&  errorId[pos] != '_')) {
+            if (errorId[pos] < 0 || (!std::isalnum(errorId[pos]) && errorId[pos] != '_')) {
                 return "Failed to add suppression. Invalid id \"" + errorId + "\"";
             }
             if (pos == 0 && std::isdigit(errorId[pos])) {
