@@ -195,10 +195,10 @@ public:
     }
 
     /**
-     * Get variable ID.
-     * @return variable ID
+     * Get declaration ID (varId used for variable in its declaration).
+     * @return declaration ID
      */
-    unsigned int varId() const {
+    unsigned int declarationId() const {
         // name may not exist for function arguments
         if (_name)
             return _name->varId();
@@ -730,6 +730,9 @@ private:
 
     /** variable symbol table */
     std::vector<const Variable *> _variableList;
+
+    /** list for missing types */
+    std::list<Type> _blankTypes;
 };
 
 #endif
