@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2012 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2013 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -46,6 +46,11 @@ struct TimerResultsData {
         : _clocks(0)
         , _numberOfResults(0) {
     }
+
+    double seconds() const {
+        double ret = (double)((unsigned long)_clocks) / (double)CLOCKS_PER_SEC;
+        return ret;
+    }
 };
 
 class CPPCHECKLIB TimerResults : public TimerResultsIntf {
@@ -76,5 +81,4 @@ private:
     bool _stopped;
 };
 
-
 #endif // TIMER_H
