@@ -546,16 +546,10 @@ public:
     /**
      * Returns the closing bracket of opening '<'. Should only be used if link()
      * is unavailable.
-     * @param closing The closing token is stored in that parameter
-     * @return success
+     * @return closing '>', ')', ']' or '}'. if no closing bracket is found, NULL is returned
      */
-    bool findClosingBracket(const Token*& closing) const;
-    bool findClosingBracket(Token*& closing) const {
-        const Token* tok;
-        bool retVal = findClosingBracket(tok);
-        closing = const_cast<Token*>(tok);
-        return retVal;
-    }
+    const Token* findClosingBracket() const;
+    Token* findClosingBracket();
 
 private:
     void next(Token *nextToken) {
