@@ -63,7 +63,7 @@ public:
      * \param unknown set to true if it's unknown if the scope is noreturn
      * \return true if scope ends with a function call that might be 'noreturn'
      */
-    static bool IsScopeNoReturn(const Token *endScopeToken, bool *unknown = 0);
+    bool IsScopeNoReturn(const Token *endScopeToken, bool *unknown = 0) const;
 
     /**
      * Tokenize code
@@ -245,10 +245,12 @@ public:
     void simplifyCompoundAssignment();
 
     /**
-     * simplify if-assignments
+     * Simplify assignments in "if" and "while" conditions
      * Example: "if(a=b);" => "a=b;if(a);"
+     * Example: "while(a=b) { f(a); }" => "a = b; while(a){ f(a); a = b; }"
+     * Example: "do { f(a); } while(a=b);" => "do { f(a); a = b; } while(a);"
      */
-    void simplifyIfAssign();
+    void simplifyIfAndWhileAssign();
 
     /**
      * Simplify multiple assignments.
