@@ -88,6 +88,7 @@ private:
         TEST_CASE(initvar_nocopy1);            // ticket #2474
         TEST_CASE(initvar_nocopy2);            // ticket #2484
         TEST_CASE(initvar_nocopy3);            // ticket #3611
+        TEST_CASE(initvar_with_member_function_this); // ticket #4824
 
         TEST_CASE(initvar_destructor);      // No variables need to be initialized in a destructor
         TEST_CASE(initvar_func_ret_func_ptr); // ticket #4449
@@ -119,6 +120,7 @@ private:
         TEST_CASE(uninitVar23); // ticket #3702
         TEST_CASE(uninitVar24); // ticket #3190
         TEST_CASE(uninitVar25); // ticket #4789
+        TEST_CASE(uninitVar26);
         TEST_CASE(uninitVarEnum);
         TEST_CASE(uninitVarStream);
         TEST_CASE(uninitVarTypedef);
@@ -1133,6 +1135,15 @@ private:
         ASSERT_EQUALS("[test.cpp:4]: (warning, inconclusive) Member variable 'A::b' is not initialized in the constructor.\n", errout.str());
     }
 
+    void initvar_with_member_function_this() {
+        check("struct Foo {\n"
+              "  Foo(int m) { this->setMember(m); }\n"
+              "  void setMember(int m) { member = m; }\n"
+              "  int member;\n"
+              "};");
+        ASSERT_EQUALS("", errout.str());
+    }
+
     void initvar_destructor() {
         check("class Fred\n"
               "{\n"
@@ -1890,6 +1901,18 @@ private:
                       "[test.cpp:42]: (warning) Member variable 'F::c' is not initialized in the constructor.\n", errout.str());
     }
 
+    void uninitVar26() {
+        check("class A {\n"
+              "    int * v;\n"
+              "    int sz;\n"
+              "public:\n"
+              "    A(int s) {\n"
+              "        v = new int [sz = s];\n"
+              "    }\n"
+              "};");
+        ASSERT_EQUALS("", errout.str());
+    }
+
     void uninitVarArray1() {
         check("class John\n"
               "{\n"
