@@ -46,9 +46,14 @@ private:
 
         TEST_CASE(testScanfArgument);
         TEST_CASE(testPrintfArgument);
+        TEST_CASE(testPosixPrintfScanfParameterPosition);  // #4900
+
+        TEST_CASE(testMicrosoftPrintfArgument); // ticket #4902
+
+        TEST_CASE(testlibrarycfg); // library configuration
     }
 
-    void check(const char code[], bool inconclusive = false, bool portability = false, Settings::PlatformType platform = Settings::Unspecified) {
+    void check(const char code[], bool inconclusive = false, bool portability = false, Settings::PlatformType platform = Settings::Unspecified, Library *lib = NULL) {
         // Clear the error buffer..
         errout.str("");
 
@@ -60,6 +65,9 @@ private:
         settings.inconclusive = inconclusive;
         settings.platform(platform);
 
+        if (lib)
+            settings.library = *lib;
+
         // Tokenize..
         Tokenizer tokenizer(&settings, this);
         std::istringstream istr(code);
@@ -715,7 +723,7 @@ private:
         // False positive tests
         check("void foo(signed char sc, unsigned char uc, short int si, unsigned short int usi) {\n"
               "  printf(\"%hhx %hhd\", sc, uc);\n"
-              "  printf(\"%hd %hi\", si, usi);\n"
+              "  printf(\"%hd %hu\", si, usi);\n"
               "}");
         ASSERT_EQUALS("", errout.str());
 
@@ -752,6 +760,88 @@ private:
                       "[test.cpp:7]: (warning) 'z' in format string (no. 1) is a length modifier and cannot be used without a conversion specifier.\n"
                       "[test.cpp:8]: (warning) 't' in format string (no. 1) is a length modifier and cannot be used without a conversion specifier.\n"
                       "[test.cpp:9]: (warning) 'L' in format string (no. 1) is a length modifier and cannot be used without a conversion specifier.\n", errout.str());
+
+        check("void foo(unsigned int i) {\n"
+              "  printf(\"%hd\", i);\n"
+              "  printf(\"%hhd\", i);\n"
+              "  printf(\"%ld\", i);\n"
+              "  printf(\"%lld\", i);\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:2]: (warning) %hd in format string (no. 1) requires a signed integer given in the argument list.\n"
+                      "[test.cpp:3]: (warning) %hhd in format string (no. 1) requires a signed integer given in the argument list.\n"
+                      "[test.cpp:4]: (warning) %ld in format string (no. 1) requires a signed integer given in the argument list.\n"
+                      "[test.cpp:5]: (warning) %lld in format string (no. 1) requires a signed integer given in the argument list.\n" , errout.str());
+
+        check("void foo(size_t s, ptrdiff_t p) {\n"
+              "  printf(\"%zd\", s);\n"
+              "  printf(\"%tu\", p);\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:2]: (warning) %zd in format string (no. 1) requires a signed integer given in the argument list.\n"
+                      "[test.cpp:3]: (warning) %tu in format string (no. 1) requires an unsigned integer given in the argument list.\n", errout.str());
+
+    }
+
+    void testPosixPrintfScanfParameterPosition() { // #4900  - No support for parameters in format strings
+        check("void foo() {"
+              "  int bar;"
+              "  printf(\"%1$d\", 1);"
+              "  printf(\"%1$d, %d, %1$d\", 1, 2);"
+              "  scanf(\"%1$d\", &bar);"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+
+        check("void foo() {\n"
+              "  int bar;\n"
+              "  printf(\"%1$d\");\n"
+              "  printf(\"%1$d, %d, %4$d\", 1, 2, 3);\n"
+              "  scanf(\"%2$d\", &bar);\n"
+              "  printf(\"%0$f\", 0.0);\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:3]: (error) printf format string has 1 parameters but only 0 are given.\n"
+                      "[test.cpp:4]: (warning) printf: referencing parameter 4 while 3 arguments given\n"
+                      "[test.cpp:5]: (warning) scanf: referencing parameter 2 while 1 arguments given\n"
+                      "[test.cpp:6]: (warning) printf: parameter positions start at 1, not 0\n"
+                      "", errout.str());
+    }
+
+
+    void testMicrosoftPrintfArgument() {
+        check("void foo() {\n"
+              "    size_t s;\n"
+              "    ptrdiff_t p;\n"
+              "    __int32 i32;\n"
+              "    unsigned __int32 u32;\n"
+              "    __int64 i64;\n"
+              "    unsigned __int64 u64;\n"
+              "    printf(\"%Id %Iu %Ix\", s, s, s);\n"
+              "    printf(\"%Id %Iu %Ix\", p, p, p);\n"
+              "    printf(\"%I32d %I32u %I32x\", i32, i32, i32);\n"
+              "    printf(\"%I32d %I32u %I32x\", u32, u32, u32);\n"
+              "    printf(\"%I64d %I64u %I64x\", i64, i64, i64);\n"
+              "    printf(\"%I64d %I64u %I64x\", u64, u64, u64);\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:8]: (warning) %Id in format string (no. 1) requires a signed integer given in the argument list.\n"
+                      "[test.cpp:9]: (warning) %Iu in format string (no. 2) requires an unsigned integer given in the argument list.\n"
+                      "[test.cpp:10]: (warning) %I32u in format string (no. 2) requires an unsigned integer given in the argument list.\n"
+                      "[test.cpp:11]: (warning) %I32d in format string (no. 1) requires a signed integer given in the argument list.\n"
+                      "[test.cpp:12]: (warning) %I64u in format string (no. 2) requires an unsigned integer given in the argument list.\n"
+                      "[test.cpp:13]: (warning) %I64d in format string (no. 1) requires a signed integer given in the argument list.\n", errout.str());
+    }
+
+    void testlibrarycfg() {
+        const char code[] = "void f() {\n"
+                            "    format(\"%s\");\n"
+                            "}";
+
+        // no error if configuration for 'format' is not provided
+        check(code);
+        ASSERT_EQUALS("", errout.str());
+
+        // error if configuration for 'format' is provided
+        Library lib;
+        lib.argumentChecks["format"][1].formatstr = true;
+        check(code, false, false, Settings::Unspecified, &lib);
+        ASSERT_EQUALS("[test.cpp:2]: (error) format format string has 1 parameters but only 0 are given.\n", errout.str());
     }
 };
 
