@@ -54,7 +54,6 @@ private:
         TEST_CASE(nullpointer19); // #3811
         TEST_CASE(nullpointer20); // #3807 (fp: return p ? (p->x() || p->y()) : z)
         TEST_CASE(nullpointer21); // #4038 (fp: if (x) p=q; else return;)
-        TEST_CASE(nullpointer22); // #4007 (fp: (uri != NULL) && (*uri == 0))
         TEST_CASE(nullpointer23); // #4665 (false positive)
         TEST_CASE(nullpointer_cast); // #4692
         TEST_CASE(nullpointer_castToVoid); // #3771
@@ -73,6 +72,7 @@ private:
         TEST_CASE(nullpointerStdString);
         TEST_CASE(nullpointerStdStream);
         TEST_CASE(functioncall);
+        TEST_CASE(functioncalllibrary); // use Library to parse function call
         TEST_CASE(crash1);
         TEST_CASE(functioncallDefaultArguments);
     }
@@ -891,12 +891,6 @@ private:
               "}");
         ASSERT_EQUALS("", errout.str());
 
-        check("void f() {\n"
-              "    Foo *p = 0;\n"
-              "    bool b = (p && (p->type() == 1));\n"
-              "}");
-        ASSERT_EQUALS("", errout.str());
-
         check("void foo()\n"
               "{\n"
               "    int sz = sizeof((*(struct dummy *)0).x);\n"
@@ -1237,14 +1231,6 @@ private:
         ASSERT_EQUALS("", errout.str());
     }
 
-    void nullpointer22() {  // #4007 - fp: (x != NULL) && (*x == 0)
-        check("void f() {\n"
-              "    int *p; p = 0;\n"
-              "    int result = p && (!*p);\n"
-              "}");
-        ASSERT_EQUALS("", errout.str());
-    }
-
     void nullpointer23() {  // #4665
         check("void f(){\n"
               "    char *c = NULL;\n"
@@ -1687,6 +1673,11 @@ private:
               "    return p[4];\n"
               "}", false, "test.cpp", false);
         ASSERT_EQUALS("[test.cpp:3]: (error) Null pointer dereference\n", errout.str());
+
+        check("void f(int x) {\n" // #4809 - passing "NULL"
+              "    itoa(x,NULL,10);\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:2]: (error) Null pointer dereference\n", errout.str());
     }
 
     void gcc_statement_expression() {
@@ -2115,6 +2106,59 @@ private:
         }
     }
 
+    void functioncalllibrary() {
+        Settings settings;
+        Tokenizer tokenizer(&settings,this);
+        std::istringstream code("void f() { int a,b; x(a,b); }");
+        tokenizer.tokenize(code,"test.c");
+        const Token *xtok = Token::findsimplematch(tokenizer.tokens(), "x");
+
+        // nothing bad..
+        {
+            Library library;
+            Library::ArgumentChecks arg;
+            library.argumentChecks["x"][1] = arg;
+            library.argumentChecks["x"][2] = arg;
+
+            std::list<const Token *> null, uninit;
+            CheckNullPointer::parseFunctionCall(*xtok, null, &library, 0U);
+            CheckNullPointer::parseFunctionCall(*xtok, uninit, &library, 1U);
+            ASSERT_EQUALS(0U, null.size());
+            ASSERT_EQUALS(0U, uninit.size());
+        }
+
+        // for 1st parameter null pointer is not ok..
+        {
+            Library library;
+            struct Library::ArgumentChecks arg;
+            library.argumentChecks["x"][1] = arg;
+            library.argumentChecks["x"][2] = arg;
+            library.argumentChecks["x"][1].notnull = true;
+
+            std::list<const Token *> null,uninit;
+            CheckNullPointer::parseFunctionCall(*xtok, null, &library, 0U);
+            CheckNullPointer::parseFunctionCall(*xtok, uninit, &library, 1U);
+            ASSERT_EQUALS(1U, null.size());
+            ASSERT_EQUALS("a", null.front()->str());
+            ASSERT_EQUALS(0U, uninit.size());
+        }
+
+        // for 2nd parameter uninit data is not ok..
+        {
+            Library library;
+            Library::ArgumentChecks arg;
+            library.argumentChecks["x"][1] = arg;
+            library.argumentChecks["x"][2] = arg;
+            library.argumentChecks["x"][2].notuninit = true;
+
+            std::list<const Token *> null,uninit;
+            CheckNullPointer::parseFunctionCall(*xtok, null, &library, 0U);
+            CheckNullPointer::parseFunctionCall(*xtok, uninit, &library, 1U);
+            ASSERT_EQUALS(0U, null.size());
+            ASSERT_EQUALS(1U, uninit.size());
+            ASSERT_EQUALS("b", uninit.front()->str());
+        }
+    }
 
     void functioncallDefaultArguments() {
 
