@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2012 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2013 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -58,108 +58,108 @@ private:
         TEST_CASE(filemaskpath4);
     }
 
-    void emptymaskemptyfile() {
+    void emptymaskemptyfile() const {
         std::vector<std::string> masks;
         PathMatch match(masks);
         ASSERT(!match.Match(""));
     }
 
-    void emptymaskpath1() {
+    void emptymaskpath1() const {
         std::vector<std::string> masks;
         PathMatch match(masks);
         ASSERT(!match.Match("src/"));
     }
 
-    void emptymaskpath2() {
+    void emptymaskpath2() const {
         std::vector<std::string> masks;
         PathMatch match(masks);
         ASSERT(!match.Match("../src/"));
     }
 
-    void emptymaskpath3() {
+    void emptymaskpath3() const {
         std::vector<std::string> masks;
         PathMatch match(masks);
         ASSERT(!match.Match("/home/user/code/src/"));
     }
 
-    void onemaskemptypath() {
+    void onemaskemptypath() const {
         std::vector<std::string> masks;
         masks.push_back("src/");
         PathMatch match(masks);
         ASSERT(!match.Match(""));
     }
 
-    void onemasksamepath() {
+    void onemasksamepath() const {
         std::vector<std::string> masks;
         masks.push_back("src/");
         PathMatch match(masks);
         ASSERT(match.Match("src/"));
     }
 
-    void onemasksamepathdifferentcase() {
+    void onemasksamepathdifferentcase() const {
         std::vector<std::string> masks;
         masks.push_back("sRc/");
         PathMatch match(masks, false);
         ASSERT(match.Match("srC/"));
     }
 
-    void onemasksamepathwithfile() {
+    void onemasksamepathwithfile() const {
         std::vector<std::string> masks;
         masks.push_back("src/");
         PathMatch match(masks);
         ASSERT(match.Match("src/file.txt"));
     }
 
-    void onemaskdifferentdir1() {
+    void onemaskdifferentdir1() const {
         std::vector<std::string> masks;
         masks.push_back("src/");
         PathMatch match(masks);
         ASSERT(!match.Match("srcfiles/file.txt"));
     }
 
-    void onemaskdifferentdir2() {
+    void onemaskdifferentdir2() const {
         std::vector<std::string> masks;
         masks.push_back("src/");
         PathMatch match(masks);
         ASSERT(!match.Match("proj/srcfiles/file.txt"));
     }
 
-    void onemaskdifferentdir3() {
+    void onemaskdifferentdir3() const {
         std::vector<std::string> masks;
         masks.push_back("src/");
         PathMatch match(masks);
         ASSERT(!match.Match("proj/mysrc/file.txt"));
     }
 
-    void onemaskdifferentdir4() {
+    void onemaskdifferentdir4() const {
         std::vector<std::string> masks;
         masks.push_back("src/");
         PathMatch match(masks);
         ASSERT(!match.Match("proj/mysrcfiles/file.txt"));
     }
 
-    void onemasklongerpath1() {
+    void onemasklongerpath1() const {
         std::vector<std::string> masks;
         masks.push_back("src/");
         PathMatch match(masks);
         ASSERT(match.Match("/tmp/src/"));
     }
 
-    void onemasklongerpath2() {
+    void onemasklongerpath2() const {
         std::vector<std::string> masks;
         masks.push_back("src/");
         PathMatch match(masks);
         ASSERT(match.Match("src/module/"));
     }
 
-    void onemasklongerpath3() {
+    void onemasklongerpath3() const {
         std::vector<std::string> masks;
         masks.push_back("src/");
         PathMatch match(masks);
         ASSERT(match.Match("project/src/module/"));
     }
 
-    void twomasklongerpath1() {
+    void twomasklongerpath1() const {
         std::vector<std::string> masks;
         masks.push_back("src/");
         masks.push_back("module/");
@@ -167,7 +167,7 @@ private:
         ASSERT(!match.Match("project/"));
     }
 
-    void twomasklongerpath2() {
+    void twomasklongerpath2() const {
         std::vector<std::string> masks;
         masks.push_back("src/");
         masks.push_back("module/");
@@ -175,7 +175,7 @@ private:
         ASSERT(match.Match("project/src/"));
     }
 
-    void twomasklongerpath3() {
+    void twomasklongerpath3() const {
         std::vector<std::string> masks;
         masks.push_back("src/");
         masks.push_back("module/");
@@ -183,7 +183,7 @@ private:
         ASSERT(match.Match("project/module/"));
     }
 
-    void twomasklongerpath4() {
+    void twomasklongerpath4() const {
         std::vector<std::string> masks;
         masks.push_back("src/");
         masks.push_back("module/");
@@ -191,56 +191,56 @@ private:
         ASSERT(match.Match("project/src/module/"));
     }
 
-    void filemask1() {
+    void filemask1() const {
         std::vector<std::string> masks;
         masks.push_back("foo.cpp");
         PathMatch match(masks);
         ASSERT(match.Match("foo.cpp"));
     }
 
-    void filemaskdifferentcase() {
+    void filemaskdifferentcase() const {
         std::vector<std::string> masks;
         masks.push_back("foo.cPp");
         PathMatch match(masks, false);
         ASSERT(match.Match("fOo.cpp"));
     }
 
-    void filemask2() {
+    void filemask2() const {
         std::vector<std::string> masks;
         masks.push_back("foo.cpp");
         PathMatch match(masks);
         ASSERT(match.Match("../foo.cpp"));
     }
 
-    void filemask3() {
+    void filemask3() const {
         std::vector<std::string> masks;
         masks.push_back("foo.cpp");
         PathMatch match(masks);
         ASSERT(match.Match("src/foo.cpp"));
     }
 
-    void filemaskpath1() {
+    void filemaskpath1() const {
         std::vector<std::string> masks;
         masks.push_back("src/foo.cpp");
         PathMatch match(masks);
         ASSERT(match.Match("src/foo.cpp"));
     }
 
-    void filemaskpath2() {
+    void filemaskpath2() const {
         std::vector<std::string> masks;
         masks.push_back("src/foo.cpp");
         PathMatch match(masks);
         ASSERT(match.Match("proj/src/foo.cpp"));
     }
 
-    void filemaskpath3() {
+    void filemaskpath3() const {
         std::vector<std::string> masks;
         masks.push_back("src/foo.cpp");
         PathMatch match(masks);
         ASSERT(!match.Match("foo.cpp"));
     }
 
-    void filemaskpath4() {
+    void filemaskpath4() const {
         std::vector<std::string> masks;
         masks.push_back("src/foo.cpp");
         PathMatch match(masks);
