@@ -56,12 +56,14 @@ private:
     void run() {
         TEST_CASE(testsimple);
         TEST_CASE(testfor);
-        TEST_CASE(teststream);
         TEST_CASE(testvolatile);
         TEST_CASE(testiterator);
         TEST_CASE(test2168);
         TEST_CASE(pointer);   // #2321 - postincrement of pointer is OK
         TEST_CASE(testHangWithInvalidCode); // #2847 - cppcheck hangs with 100% cpu load
+        TEST_CASE(testtemplate); // #4686
+        TEST_CASE(testmember);
+        TEST_CASE(testcomma);
     }
 
     void testHangWithInvalidCode() {
@@ -83,7 +85,7 @@ private:
               "    k--;\n"
               "    std::cout << k << std::endl;\n"
               "    return 0;\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("", errout.str());
 
         check("class K {};"
@@ -94,7 +96,7 @@ private:
               "    k++;\n"
               "    std::cout << k << std::endl;\n"
               "    return 0;\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("[test.cpp:5]: (performance) Prefer prefix ++/-- operators for non-primitive types.\n", errout.str());
 
         check("struct K {};"
@@ -102,7 +104,14 @@ private:
               "{\n"
               "    K k(0);\n"
               "    k++;\n"
-              "}\n");
+              "}");
+        ASSERT_EQUALS("[test.cpp:4]: (performance) Prefer prefix ++/-- operators for non-primitive types.\n", errout.str());
+
+        check("struct K {};\n"
+              "void foo(K& k)\n"
+              "{\n"
+              "    k++;\n"
+              "}");
         ASSERT_EQUALS("[test.cpp:4]: (performance) Prefer prefix ++/-- operators for non-primitive types.\n", errout.str());
 
         check("union K {};"
@@ -110,7 +119,7 @@ private:
               "{\n"
               "    K k(0);\n"
               "    k++;\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("[test.cpp:4]: (performance) Prefer prefix ++/-- operators for non-primitive types.\n", errout.str());
 
         check("class K {};"
@@ -123,7 +132,7 @@ private:
               "    }\n"
               "    std::cout << k << std::endl;\n"
               "    return 0;\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("[test.cpp:6]: (performance) Prefer prefix ++/-- operators for non-primitive types.\n", errout.str());
 
         check("class K {};"
@@ -137,7 +146,7 @@ private:
               "    k++;\n"
               "    std::cout << k << std::endl;\n"
               "    return 0;\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("[test.cpp:8]: (performance) Prefer prefix ++/-- operators for non-primitive types.\n", errout.str());
 
 
@@ -149,7 +158,7 @@ private:
               "    k--;\n"
               "    std::cout << k << std::endl;\n"
               "    return 0;\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("[test.cpp:5]: (performance) Prefer prefix ++/-- operators for non-primitive types.\n", errout.str());
 
         check("class K {};"
@@ -160,7 +169,7 @@ private:
               "    ++k;\n"
               "    std::cout << k << std::endl;\n"
               "    return 0;\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("", errout.str());
 
         check("class K {};"
@@ -171,7 +180,7 @@ private:
               "    --k;\n"
               "    std::cout << k << std::endl;\n"
               "    return 0;\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("", errout.str());
 
     }
@@ -183,7 +192,7 @@ private:
               "         std::cout << i << std::endl;\n"
               "    }\n"
               "    return 0;\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("", errout.str());
 
         check("class K {};\n"
@@ -193,7 +202,7 @@ private:
               "         std::cout << i << std::endl;\n"
               "    }\n"
               "    return 0;\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("[test.cpp:4]: (performance) Prefer prefix ++/-- operators for non-primitive types.\n", errout.str());
 
         check("class K {};\n"
@@ -203,7 +212,7 @@ private:
               "         std::cout << i << std::endl;\n"
               "    }\n"
               "    return 0;\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("", errout.str());
 
         check("class K {};\n"
@@ -213,7 +222,7 @@ private:
               "         std::cout << i << std::endl;\n"
               "    }\n"
               "    return 0;\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("[test.cpp:4]: (performance) Prefer prefix ++/-- operators for non-primitive types.\n", errout.str());
 
         check("class K {};\n"
@@ -223,45 +232,12 @@ private:
               "         std::cout << i << std::endl;\n"
               "    }\n"
               "    return 0;\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("", errout.str());
 
 
     }
 
-    void teststream() {
-        check("int main()\n"
-              "{\n"
-              "    int k(0);\n"
-              "    std::cout << k << std::endl;\n"
-              "    std::cout << k++ << std::endl;\n"
-              "    std::cout << k-- << std::endl;\n"
-              "    return 0;\n"
-              "}\n");
-        ASSERT_EQUALS("", errout.str());
-
-        check("class K {};\n"
-              "int main()\n"
-              "{\n"
-              "    K k(0);\n"
-              "    std::cout << k << std::endl;\n"
-              "    std::cout << k-- << std::endl;\n"
-              "    return 0;\n"
-              "}\n");
-        ASSERT_EQUALS("[test.cpp:6]: (performance) Prefer prefix ++/-- operators for non-primitive types.\n", errout.str());
-
-        check("class K {};\n"
-              "int main()\n"
-              "{\n"
-              "    K k(0);\n"
-              "    std::cout << k << std::endl;\n"
-              "    std::cout << ++k << std::endl;\n"
-              "    std::cout << --k << std::endl;\n"
-              "    return 0;\n"
-              "}\n");
-        ASSERT_EQUALS("", errout.str());
-    }
-
     void testvolatile() {
         check("class K {};\n"
               "int main()\n"
@@ -271,7 +247,7 @@ private:
               "    k++;\n"
               "    std::cout << k << std::endl;\n"
               "    return 0;\n"
-              "}\n");
+              "}");
         TODO_ASSERT_EQUALS("",
                            "[test.cpp:6]: (performance) Prefer prefix ++/-- operators for non-primitive types.\n", errout.str());
     }
@@ -287,7 +263,7 @@ private:
               "    }\n"
               "    v.clear();\n"
               "    return 0;\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("[test.cpp:6]: (performance) Prefer prefix ++/-- operators for non-primitive types.\n", errout.str());
 
         check("int main() {\n"
@@ -301,7 +277,7 @@ private:
               "       it++;\n"
               "    }\n"
               "    return 0;\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("[test.cpp:9]: (performance) Prefer prefix ++/-- operators for non-primitive types.\n", errout.str());
 
         check("int main() {\n"
@@ -314,7 +290,7 @@ private:
               "       it++;\n"
               "    }\n"
               "    return 0;\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("[test.cpp:8]: (performance) Prefer prefix ++/-- operators for non-primitive types.\n", errout.str());
 
         check("int main() {\n"
@@ -328,14 +304,14 @@ private:
               "       rit--;\n"
               "    }\n"
               "    return 0;\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("[test.cpp:9]: (performance) Prefer prefix ++/-- operators for non-primitive types.\n", errout.str());
 
     }
 
     void test2168() {
         check("--> declare allocator lock here\n"
-              "int main(){}\n");
+              "int main(){}");
         ASSERT_EQUALS("", errout.str());
     }
 
@@ -345,6 +321,47 @@ private:
               "p++;\n");
         ASSERT_EQUALS("", errout.str());
     }
+
+    void testtemplate() {
+        check("bool foo() {\n"
+              "    std::vector<FilterConfigCacheEntry>::iterator aIter(aImport.begin());\n"
+              "    aIter++;\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:3]: (performance) Prefer prefix ++/-- operators for non-primitive types.\n", errout.str());
+    }
+
+    void testmember() {
+        check("bool foo() {\n"
+              "    class A {}; class B {A a;};\n"
+              "    B b;\n"
+              "    b.a++;\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:4]: (performance) Prefer prefix ++/-- operators for non-primitive types.\n", errout.str());
+
+        check("bool foo() {\n"
+              "    class A {}; class B {A a;};\n"
+              "    B b;\n"
+              "    foo(b.a++);\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void testcomma() {
+        check("bool foo(int i) {\n"
+              "    class A {};\n"
+              "    A a;\n"
+              "    i++, a++;\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:4]: (performance) Prefer prefix ++/-- operators for non-primitive types.\n", errout.str());
+
+        check("bool foo(int i) {\n"
+              "    class A {};\n"
+              "    A a;\n"
+              "    foo(i, a++);\n"
+              "    foo(a++, i);\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+    }
 };
 
 REGISTER_TEST(TestPostfixOperator)
