@@ -39,6 +39,7 @@ private:
         TEST_CASE(sizeofForArrayParameter);
         TEST_CASE(sizeofForNumericParameter);
         TEST_CASE(suspiciousSizeofCalculation);
+        TEST_CASE(sizeofVoid);
     }
 
     void check(const char code[]) {
@@ -47,6 +48,7 @@ private:
 
         Settings settings;
         settings.addEnabled("warning");
+        settings.addEnabled("portability");
         settings.inconclusive = true;
 
         // Tokenize..
@@ -488,4 +490,128 @@ private:
               "}");
         ASSERT_EQUALS("", errout.str());
     }
-};
\ No newline at end of file
+
+    void sizeofVoid() {
+        check("void f() {\n"
+              "  int size = sizeof(void);\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:2]: (portability) Behaviour of 'sizeof(void)' is not covered by the ISO C standard.\n", errout.str());
+
+        check("void f() {\n"
+              "  void* p;\n"
+              "  int size = sizeof(*p);\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:3]: (portability) '*p' is of type 'void', the behaviour of 'sizeof(void)' is not covered by the ISO C standard.\n", errout.str());
+
+        check("void f() {\n"
+              "  void* p = malloc(10);\n"
+              "  int* p2 = p + 4;\n"
+              "  int* p3 = p - 1;\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:3]: (portability) 'p' is of type 'void *'. When using void pointers in calculations, the behaviour is undefined.\n"
+                      "[test.cpp:4]: (portability) 'p' is of type 'void *'. When using void pointers in calculations, the behaviour is undefined.\n", errout.str());
+
+        check("void f() {\n"
+              "  void* p1 = malloc(10);\n"
+              "  void* p2 = malloc(5);\n"
+              "  p1--;\n"
+              "  p2++;\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:4]: (portability) 'p1' is of type 'void *'. When using void pointers in calculations, the behaviour is undefined.\n"
+                      "[test.cpp:5]: (portability) 'p2' is of type 'void *'. When using void pointers in calculations, the behaviour is undefined.\n", errout.str());
+
+        check("void f() {\n"
+              "  void** p1;\n"
+              "  int j = sizeof(*p1);\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+
+        check("void f() {\n"
+              "  void* p1[5];\n"
+              "  int j = sizeof(*p1);\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+
+        // Calculations on void* with casts
+
+        check("void f(void *data) {\n"
+              "  *((unsigned char *)data + 1) = 0;\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+
+        check("void f(void *data) {\n"
+              "  *((unsigned char *)(data) + 1) = 0;\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+
+        check("void f(void *data) {\n"
+              "  unsigned char* c = (unsigned char *)(data + 1);\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:2]: (portability) 'data' is of type 'void *'. When using void pointers in calculations, the behaviour is undefined.\n", errout.str());
+
+        check("void f(void *data) {\n"
+              "  unsigned char* c = (unsigned char *)data++;\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:2]: (portability) 'data' is of type 'void *'. When using void pointers in calculations, the behaviour is undefined.\n", errout.str());
+
+        check("void f(void *data) {\n"
+              "  void* data2 = (void *)data + 1;\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:2]: (portability) 'data' is of type 'void *'. When using void pointers in calculations, the behaviour is undefined.\n", errout.str());
+
+        // #4908 (void pointer as a member of a struct/class)
+        check("struct FOO {\n"
+              "  void *data;\n"
+              "};\n"
+              "char f(struct FOO foo) {\n"
+              "  char x = *((char*)(foo.data+1));\n"
+              "  foo.data++;\n"
+              "  return x;\n"
+              "}\n");
+        ASSERT_EQUALS("[test.cpp:5]: (portability) 'foo.data' is of type 'void *'. When using void pointers in calculations, the behaviour is undefined.\n"
+                      "[test.cpp:6]: (portability) 'foo.data' is of type 'void *'. When using void pointers in calculations, the behaviour is undefined.\n", errout.str());
+
+        check("struct FOO {\n"
+              "  void *data;\n"
+              "};\n"
+              "char f(struct FOO foo) {\n"
+              "  char x = *((char*)foo.data+1);\n"
+              "  return x;\n"
+              "}\n"
+              "char f2(struct FOO foo) {\n"
+              "  char x = *((char*)((FOO)foo).data + 1);\n"
+              "  return x;\n"
+              "}\n"
+              "char f3(struct FOO* foo) {\n"
+              "  char x = *((char*)foo->data + 1);\n"
+              "  return x;\n"
+              "}\n"
+              "struct BOO {\n"
+              "  FOO data;\n"
+              "};\n"
+              "void f4(struct BOO* boo) {\n"
+              "  char c = *((char*)boo->data.data + 1);\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+
+        check("struct FOO {\n"
+              "  void *data;\n"
+              "};\n"
+              "char f(struct FOO* foo) {\n"
+              "  *(foo[1].data + 1) = 0;\n"
+              "}\n");
+        ASSERT_EQUALS("[test.cpp:5]: (portability) 'foo[1].data' is of type 'void *'. When using void pointers in calculations, the behaviour is undefined.\n", errout.str());
+
+        check("struct FOO {\n"
+              "  void *data;\n"
+              "};\n"
+              "void f2(struct FOO* foo) {\n"
+              "  (foo[0]).data++;\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:5]: (portability) '(foo[0]).data' is of type 'void *'. When using void pointers in calculations, the behaviour is undefined.\n", errout.str());
+    }
+
+};
+
+REGISTER_TEST(TestSizeof)
+
