@@ -41,11 +41,12 @@ private:
         TEST_CASE(suppressionsFileNameWithExtraPath);
         TEST_CASE(suppressionsSettings);
         TEST_CASE(suppressionsMultiFile);
+        TEST_CASE(suppressionsPathSeparator);
 
         TEST_CASE(inlinesuppress_unusedFunction); // #4210 - unusedFunction
     }
 
-    void suppressionsBadId1() {
+    void suppressionsBadId1() const {
         Suppressions suppressions;
         std::istringstream s1("123");
         ASSERT_EQUALS("Failed to add suppression. Invalid id \"123\"", suppressions.parseFile(s1));
@@ -54,7 +55,7 @@ private:
         ASSERT_EQUALS("", suppressions.parseFile(s2));
     }
 
-    void suppressionsDosFormat() {
+    void suppressionsDosFormat() const {
         Suppressions suppressions;
         std::istringstream s("abc\r\ndef\r\n");
         ASSERT_EQUALS("", suppressions.parseFile(s));
@@ -62,16 +63,16 @@ private:
         ASSERT_EQUALS(true, suppressions.isSuppressed("def", "test.cpp", 1));
     }
 
-    void suppressionsFileNameWithColon() {
+    void suppressionsFileNameWithColon() const {
         Suppressions suppressions;
         std::istringstream s("errorid:c:\\foo.cpp\nerrorid:c:\\bar.cpp:12");
         ASSERT_EQUALS("", suppressions.parseFile(s));
-        ASSERT_EQUALS(true, suppressions.isSuppressed("errorid", "c:\\foo.cpp", 1111));
-        ASSERT_EQUALS(false, suppressions.isSuppressed("errorid", "c:\\bar.cpp", 10));
-        ASSERT_EQUALS(true, suppressions.isSuppressed("errorid", "c:\\bar.cpp", 12));
+        ASSERT_EQUALS(true, suppressions.isSuppressed("errorid", "c:/foo.cpp", 1111));
+        ASSERT_EQUALS(false, suppressions.isSuppressed("errorid", "c:/bar.cpp", 10));
+        ASSERT_EQUALS(true, suppressions.isSuppressed("errorid", "c:/bar.cpp", 12));
     }
 
-    void suppressionsGlob() {
+    void suppressionsGlob() const {
         // Check for syntax errors in glob
         {
             Suppressions suppressions;
@@ -105,7 +106,7 @@ private:
         }
     }
 
-    void suppressionsFileNameWithExtraPath() {
+    void suppressionsFileNameWithExtraPath() const {
         // Ticket #2797
         Suppressions suppressions;
         suppressions.addSuppression("errorid", "./a.c", 123);
@@ -120,6 +121,7 @@ private:
         CppCheck cppCheck(*this, true);
         Settings& settings = cppCheck.settings();
         settings._inlineSuppressions = true;
+        settings.addEnabled("information");
         if (!suppression.empty()) {
             std::string r = settings.nomsg.addSuppressionLine(suppression);
             ASSERT_EQUALS("", r);
@@ -140,6 +142,7 @@ private:
         Settings settings;
         settings._jobs = 1;
         settings._inlineSuppressions = true;
+        settings.addEnabled("information");
         if (!suppression.empty()) {
             std::string r = settings.nomsg.addSuppressionLine(suppression);
             ASSERT_EQUALS("", r);
@@ -161,6 +164,7 @@ private:
         CppCheck cppCheck(*this, true);
         Settings& settings = cppCheck.settings();
         settings._inlineSuppressions = true;
+        settings.addEnabled("information");
         if (!suppression.empty())
             settings.nomsg.addSuppressionLine(suppression);
 
@@ -313,7 +317,13 @@ private:
         ASSERT_EQUALS("", errout.str());
     }
 
-    void inlinesuppress_unusedFunction() { // #4210 - wrong report of "unmatchedSuppression" for "unusedFunction"
+    void suppressionsPathSeparator() const {
+        Suppressions suppressions;
+        suppressions.addSuppressionLine("*:test\\*");
+        ASSERT_EQUALS(true, suppressions.isSuppressed("someid", "test/foo/bar.cpp", 142));
+    }
+
+    void inlinesuppress_unusedFunction() const { // #4210 - wrong report of "unmatchedSuppression" for "unusedFunction"
         Suppressions suppressions;
         suppressions.addSuppression("unusedFunction", "test.c", 3U);
         ASSERT_EQUALS(true, suppressions.getUnmatchedLocalSuppressions("test.c").empty());
