@@ -120,6 +120,9 @@ private:
         TEST_CASE(isVariableDeclarationPointerConst);
         TEST_CASE(isVariableDeclarationRValueRef);
 
+        TEST_CASE(arrayMemberVar1);
+        TEST_CASE(arrayMemberVar2);
+        TEST_CASE(arrayMemberVar3);
         TEST_CASE(staticMemberVar);
 
         TEST_CASE(hasRegularFunction);
@@ -191,6 +194,9 @@ private:
         TEST_CASE(symboldatabase30);
         TEST_CASE(symboldatabase31);
         TEST_CASE(symboldatabase33); // ticket #4682 (false negatives)
+        TEST_CASE(symboldatabase34); // ticket #4694 (segmentation fault)
+        TEST_CASE(symboldatabase35); // ticket #4806 (segmentation fault)
+        TEST_CASE(symboldatabase36); // ticket #4892 (segmentation fault)
 
         TEST_CASE(isImplicitlyVirtual);
 
@@ -542,6 +548,66 @@ private:
         ASSERT(var.tokens()->tokAt(2)->scope() != 0);
     }
 
+    void arrayMemberVar1() {
+        const char code[] = "struct Foo {\n"
+                            "    int x;\n"
+                            "};\n"
+                            "void f() {\n"
+                            "    struct Foo foo[10];\n"
+                            "    foo[1].x = 123;\n"  // <- x should get a variable() pointer
+                            "}";
+
+        Settings settings;
+        Tokenizer tokenizer(&settings, this);
+        std::istringstream istr(code);
+        tokenizer.tokenize(istr, "test.cpp");
+
+        const Token *tok = Token::findmatch(tokenizer.tokens(), ". x");
+        tok = tok ? tok->next() : NULL;
+        ASSERT(tok && tok->variable() && Token::Match(tok->variable()->typeStartToken(), "int x ;"));
+        ASSERT(tok && tok->varId() == 0U); // It's possible to set a varId
+    }
+
+    void arrayMemberVar2() {
+        const char code[] = "struct Foo {\n"
+                            "    int x;\n"
+                            "};\n"
+                            "void f() {\n"
+                            "    struct Foo foo[10][10];\n"
+                            "    foo[1][2].x = 123;\n"  // <- x should get a variable() pointer
+                            "}";
+
+        Settings settings;
+        Tokenizer tokenizer(&settings, this);
+        std::istringstream istr(code);
+        tokenizer.tokenize(istr, "test.cpp");
+
+        const Token *tok = Token::findmatch(tokenizer.tokens(), ". x");
+        tok = tok ? tok->next() : NULL;
+        ASSERT(tok && tok->variable() && Token::Match(tok->variable()->typeStartToken(), "int x ;"));
+        ASSERT(tok && tok->varId() == 0U); // It's possible to set a varId
+    }
+
+    void arrayMemberVar3() {
+        const char code[] = "struct Foo {\n"
+                            "    int x;\n"
+                            "};\n"
+                            "void f() {\n"
+                            "    struct Foo foo[10];\n"
+                            "    (foo[1]).x = 123;\n"  // <- x should get a variable() pointer
+                            "}";
+
+        Settings settings;
+        Tokenizer tokenizer(&settings, this);
+        std::istringstream istr(code);
+        tokenizer.tokenize(istr, "test.cpp");
+
+        const Token *tok = Token::findmatch(tokenizer.tokens(), ". x");
+        tok = tok ? tok->next() : NULL;
+        ASSERT(tok && tok->variable() && Token::Match(tok->variable()->typeStartToken(), "int x ;"));
+        ASSERT(tok && tok->varId() == 0U); // It's possible to set a varId
+    }
+
     void staticMemberVar() {
         GET_SYMBOL_DB("class Foo {\n"
                       "    static const double d;\n"
@@ -1496,6 +1562,26 @@ private:
         ASSERT(db && db->functionScopes.size() == 1);
     }
 
+    void symboldatabase34() { // ticket #4694
+        check("typedef _Atomic(int(A::*)) atomic_mem_ptr_to_int;\n"
+              "typedef _Atomic(int)&atomic_int_ref;\n"
+              "struct S {\n"
+              "  _Atomic union { int n; };\n"
+              "};");
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void symboldatabase35() { // ticket #4806 and #4841
+        check("class FragmentQueue : public CL_NS(util)::PriorityQueue<CL_NS(util)::Deletor::Object<TextFragment> >\n"
+              "{};");
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void symboldatabase36() { // ticket #4892
+        check("void struct ( ) { if ( 1 ) } int main ( ) { }");
+        ASSERT_EQUALS("", errout.str());
+    }
+
     void isImplicitlyVirtual() {
         {
             GET_SYMBOL_DB("class Base {\n"
