@@ -51,6 +51,8 @@ private:
         TEST_CASE(multipleFiles);   // same function name in multiple files
 
         TEST_CASE(lineNumber); // Ticket 3059
+
+        TEST_CASE(ignore_declaration); // ignore declaration
     }
 
     void check(const char code[]) {
@@ -76,7 +78,7 @@ private:
               "{\n"
               "    if (f1())\n"
               "    { }\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("", errout.str());
     }
 
@@ -84,7 +86,7 @@ private:
         check("int f1()\n"
               "{\n"
               "    return f1();\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("", errout.str());
     }
 
@@ -92,7 +94,7 @@ private:
         check("char * foo()\n"
               "{\n"
               "    return *foo();\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("", errout.str());
     }
 
@@ -100,7 +102,7 @@ private:
         check("void f1()\n"
               "{\n"
               "    void (*f)() = cond ? f1 : NULL;\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("", errout.str());
     }
 
@@ -109,7 +111,7 @@ private:
               "{\n"
               "    if (cond) ;\n"
               "    else f1();\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("", errout.str());
     }
 
@@ -122,7 +124,7 @@ private:
               "{\n"
               "    f(&abc::foo);\n"
               "    return 0\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("", errout.str());
 
         check("namespace abc {\n"
@@ -133,7 +135,7 @@ private:
               "{\n"
               "    f = &abc::foo;\n"
               "    return 0\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("", errout.str());
 
         check("namespace abc {\n"  // #3875
@@ -144,7 +146,7 @@ private:
               "{\n"
               "    f(abc::foo);\n"
               "    return 0\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("", errout.str());
     }
 
@@ -155,7 +157,7 @@ private:
               "{\n"
               "    foo<int>();\n"
               "    return 0\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("", errout.str());
     }
 
@@ -165,12 +167,12 @@ private:
               "template<class T> void g()\n"
               "{\n"
               "    f();\n"
-              "}\n");
+              "}");
         ASSERT_EQUALS("", errout.str());
     }
 
     void throwIsNotAFunction() {
-        check("struct A {void f() const throw () {}}; int main() {A a; a.f();}\n");
+        check("struct A {void f() const throw () {}}; int main() {A a; a.f();}");
         ASSERT_EQUALS("", errout.str());
     }
 
@@ -193,20 +195,20 @@ private:
     }
 
     void unusedMain() {
-        check("int main() { }\n");
+        check("int main() { }");
         ASSERT_EQUALS("", errout.str());
 
-        check("int _tmain() { }\n");
+        check("int _tmain() { }");
         ASSERT_EQUALS("", errout.str());
 
-        check("int WinMain() { }\n");
+        check("int WinMain() { }");
         ASSERT_EQUALS("", errout.str());
     }
 
     void initializationIsNotAFunction() {
         check("struct B: N::A {\n"
               "  B(): N::A() {};\n"
-              "};\n");
+              "};");
         ASSERT_EQUALS("", errout.str());
     }
 
@@ -257,6 +259,16 @@ private:
         ASSERT_EQUALS("[test.cpp:2]: (style) The function 'bar' is never used.\n"
                       "[test.cpp:1]: (style) The function 'foo' is never used.\n", errout.str());
     }
+
+    void ignore_declaration() {
+        check("void f();\n"
+              "void f() {}");
+        ASSERT_EQUALS("[test.cpp:2]: (style) The function 'f' is never used.\n", errout.str());
+
+        check("void f(void) {}\n"
+              "void (*list[])(void) = {f}");
+        ASSERT_EQUALS("", errout.str());
+    }
 };
 
 REGISTER_TEST(TestUnusedFunctions)
