@@ -82,7 +82,7 @@ static void compilefiles(std::ostream &fout, const std::vector<std::string> &fil
         getDeps(files[i], depfiles);
         for (unsigned int dep = 0; dep < depfiles.size(); ++dep)
             fout << " " << depfiles[dep];
-        fout << "\n\t$(CXX) $(CPPFLAGS) $(CXXFLAGS) " << args << " -c -o " << objfile(files[i]) << " " << builddir(files[i]) << "\n\n";
+        fout << "\n\t$(CXX) " << args << " $(CPPFLAGS) $(CXXFLAGS) -c -o " << objfile(files[i]) << " " << builddir(files[i]) << "\n\n";
     }
 }
 
@@ -175,6 +175,9 @@ int main(int argc, char **argv)
         if (fout1.is_open()) {
             fout1 << "# no manual edits - this file is autogenerated by dmake\n\n";
             fout1 << "include($$PWD/pcrerules.pri)\n";
+            fout1 << "BASEPATH = ../externals/tinyxml/\n";
+            fout1 << "include($$PWD/../externals/tinyxml/tinyxml.pri)\n";
+            fout1 << "BASEPATH = ../lib/\n";
             fout1 << "INCLUDEPATH += ../externals/tinyxml\n";
             fout1 << "HEADERS += $${BASEPATH}check.h \\\n";
             for (unsigned int i = 0; i < libfiles.size(); ++i) {
@@ -321,7 +324,7 @@ int main(int argc, char **argv)
 
     makeConditionalVariable(fout, "CXX", "g++");
     makeConditionalVariable(fout, "PREFIX", "/usr");
-    makeConditionalVariable(fout, "INCLUDE_FOR_LIB", "-Ilib");
+    makeConditionalVariable(fout, "INCLUDE_FOR_LIB", "-Ilib -Iexternals -Iexternals/tinyxml");
     makeConditionalVariable(fout, "INCLUDE_FOR_CLI", "-Ilib -Iexternals -Iexternals/tinyxml");
     makeConditionalVariable(fout, "INCLUDE_FOR_TEST", "-Ilib -Icli -Iexternals -Iexternals/tinyxml");
 
