@@ -33,7 +33,7 @@ private:
     std::time_t stopTime;
 
 public:
-    CppcheckExecutor(std::size_t linenr, bool hang)
+    CppcheckExecutor(const char *defines, std::size_t linenr, bool hang)
         : ErrorLogger()
         , cppcheck(*this,false)
         , foundLine(false)
@@ -42,6 +42,8 @@ public:
         if (!hang)
             pattern = ":" + MathLib::longToString(linenr) + "]";
 
+        if (defines)
+            cppcheck.settings().userDefines = defines;
         cppcheck.settings().addEnabled("all");
         cppcheck.settings().inconclusive = true;
         cppcheck.settings()._force = true;
@@ -78,6 +80,7 @@ struct ReduceSettings {
     std::size_t linenr;
     bool hang;
     unsigned int maxtime;
+    const char *defines;
 };
 
 static bool test(const ReduceSettings &settings, const std::vector<std::string> &filedata, const std::size_t line1, const std::size_t line2)
@@ -94,7 +97,7 @@ static bool test(const ReduceSettings &settings, const std::vector<std::string>
         fout << ((i>=line1 && i<=line2) ? "" : filedata[i]) << std::endl;
     fout.close();
 
-    CppcheckExecutor cppcheck(settings.linenr, settings.hang);
+    CppcheckExecutor cppcheck(settings.defines, settings.linenr, settings.hang);
     return cppcheck.run(tempfilename.c_str(), settings.maxtime);
 }
 
@@ -262,22 +265,31 @@ static bool removeBlocksOfCode(const ReduceSettings &settings, std::vector<std::
 
                 // does code block start with "{"
                 std::size_t pos2 = pos;
-                if (filedata[pos].find("(") != std::string::npos && filedata[pos].find(")")==std::string::npos) {
-                    ++pos2;
-                    while (pos2+2U < filedata.size() && !filedata[pos2].empty() && filedata[pos2].find_first_of("(){}") == std::string::npos)
+
+                // struct X { ..
+                if (filedata[pos].find_first_of("();}") == std::string::npos && filedata[pos].at(filedata[pos].size()-1U) == '{') {
+
+                }
+
+                // function declaration ..
+                else {
+                    if (filedata[pos].find("(") != std::string::npos && filedata[pos].find(")")==std::string::npos) {
                         ++pos2;
-                    if (filedata[pos2].find_first_of("({}")!=std::string::npos || filedata[pos2].find(")") == std::string::npos)
+                        while (pos2+2U < filedata.size() && !filedata[pos2].empty() && filedata[pos2].find_first_of("(){}") == std::string::npos)
+                            ++pos2;
+                        if (filedata[pos2].find_first_of("({}")!=std::string::npos || filedata[pos2].find(")") == std::string::npos)
+                            break;
+                    }
+                    pos2++;
+                    if (pos2 < filedata.size() && !filedata[pos2].empty() && filedata[pos2].at(filedata[pos2].find_first_not_of(" ")) == ':') {
+                        pos2++;
+                        while (pos2 < filedata.size() && !filedata[pos2].empty() && filedata[pos2].at(filedata[pos2].find_first_not_of(" ")) == ',')
+                            pos2++;
+                    }
+                    if (pos2+2U >= filedata.size() || filedata[pos2] != "{")
                         break;
                 }
                 pos2++;
-                if (pos2 < filedata.size() && !filedata[pos2].empty() && filedata[pos2].at(filedata[pos2].find_first_not_of(" ")) == ':') {
-                    pos2++;
-                    while (pos2 < filedata.size() && !filedata[pos2].empty() && filedata[pos2].at(filedata[pos2].find_first_not_of(" ")) == ',')
-                        pos2++;
-                }
-                if (pos2+2U >= filedata.size() || filedata[pos2] != "{")
-                    break;
-                pos2++;
 
                 // find end of block..
                 int level = 0;
@@ -575,6 +587,8 @@ int main(int argc, char *argv[])
             settings.hang = true;
         } else if (strncmp(argv[i], "--maxtime=", 10) == 0)
             settings.maxtime = std::atoi(argv[i] + 10);
+        else if (strncmp(argv[i],"--cfg=",6)==0)
+            settings.defines = argv[i] + 6;
         else if (settings.filename==NULL && strchr(argv[i],'.'))
             settings.filename = argv[i];
         else if (settings.linenr == 0U && MathLib::isInt(argv[i]))
@@ -587,7 +601,7 @@ int main(int argc, char *argv[])
 
     if ((!settings.hang && settings.linenr == 0U) || settings.filename == NULL) {
         std::cerr << "Syntax:" << std::endl
-                  << argv[0] << " [--stdout] [--hang] filename [linenr]" << std::endl;
+                  << argv[0] << " [--stdout] [--cfg=X] [--hang] [--maxtime=60] filename [linenr]" << std::endl;
         return EXIT_FAILURE;
     }
 
@@ -595,7 +609,7 @@ int main(int argc, char *argv[])
 
     // Execute Cppcheck on the file..
     {
-        CppcheckExecutor cppcheck(settings.linenr, settings.hang);
+        CppcheckExecutor cppcheck(settings.defines, settings.linenr, settings.hang);
         if (!cppcheck.run(settings.filename, settings.maxtime)) {
             std::cerr << "Can't reproduce false positive at line " << settings.linenr << std::endl;
             return EXIT_FAILURE;
@@ -664,7 +678,7 @@ int main(int argc, char *argv[])
         std::ofstream fout;
         if (!print)
             fout.open(outfilename.c_str());
-        std::ostream &os = stdout ? std::cout : fout;
+        std::ostream &os = print ? std::cout : fout;
         for (std::size_t i = 0; i < filedata.size(); i++) {
             if (!filedata[i].empty())
                 os << filedata[i] << std::endl;
